K = int(input())
S = list(map(int, input().split()))
T = list(map(int, input().split()))


def dist_big(S, T):
    global K
    if K <= 2:
        D = [abs(S[i] - T[i]) for i in range(2)]
        ret = min(D) * 2
        ret += (max(D) - min(D)) * (K + 1)
        return ret
    else:
        return abs((S[0] + S[1]) - (T[0] + T[1])) + abs((S[0] - S[1]) - (T[0] - T[1]))


def dist(S, T):
    global K
    SB = [(s // K) for s in S]
    TB = [(t // K) for t in T]
    if SB == TB and sum(SB) % 2 == 1:
        return 0

    if sum(SB) % 2 == 0:
        Sn = 4
        Sout = [-(S[0] + 1) % K + 1, S[0] % K + 1, -(S[1] + 1) % K + 1, S[1] % K + 1]
        SB = [list(SB) for _ in range(Sn)]
        SB[0][0] += 1
        SB[1][0] -= 1
        SB[2][1] += 1
        SB[3][1] -= 1
    else:
        SB = [SB]
        Sout = [0]
        Sn = 1

    if sum(TB) % 2 == 0:
        Tn = 4
        Tout = [-(T[0] + 1) % K + 1, T[0] % K + 1, -(T[1] + 1) % K + 1, T[1] % K + 1]
        TB = [list(TB) for _ in range(Tn)]
        TB[0][0] += 1
        TB[1][0] -= 1
        TB[2][1] += 1
        TB[3][1] -= 1
    else:
        TB = [TB]
        Tout = [0]
        Tn = 1

    D = [[dist_big(SB[si], TB[ti]) + Sout[si] + Tout[ti] for si in range(Sn)] for ti in range(Tn)]
    ret = min(min(D[ti]) for ti in range(Tn))
    if ret > abs(S[0] - T[0]) + abs(S[1] - T[1]):
        ret = abs(S[0] - T[0]) + abs(S[1] - T[1])
    return ret


print(dist(S, T))



# 入力の受け取り
N, P, Q, R, S = map(int, input().split())
# 最初に[0]を埋めて番号をずらす
A = [0] + list(map(int, input().split()))
# 1~P-1
A1 = A[1:P]
# P~Q
A2 = A[P : Q + 1]
# Q+1~R-1
A3 = A[Q + 1 : R]
# R~S
A4 = A[R : S + 1]
# S+1~N
A5 = A[S + 1 : N + 1]

# つなげる
B = A1 + A4 + A3 + A2 + A5

# 出力(「*」をつけるとかっこなしで出力できる)
print(B)



def find_differing_cell(N, A, B):
    for i in range(N):
        for j in range(N):
            if A[i][j] != B[i][j]:
                # print(i+1, j+1)
                return (i + 1, j + 1)


N = int(input())
A = [["a" for x in range(N)] for y in range(N)]
B = [["a" for x in range(N)] for y in range(N)]

for i in range(N):
    ch = str(input())
    for j in range(N):
        A[i][j] = ch[j]

for i in range(N):
    ch = str(input())
    for j in range(N):
        B[i][j] = ch[j]

# print(N,A,B)
find_differing_cell(N, A, B)



N = int(input())
A = list(map(int, input().split()))
B = list(map(int, input().split()))


def sort_data(data):
    odd_pos = []
    for i, a in enumerate(data):
        if a % 2:
            odd_pos.append(i)

    flag = 0
    for i1, i2 in zip(odd_pos, odd_pos[1:]):
        if i2 - i1 <= 2:
            flag = 1
            break
    if flag:
        odd = []
        even = []
        for a in data:
            if a % 2:
                odd.append(a)
            else:
                even.append(a)
        odd.sort()
        if len(even) >= 3:
            even.sort()
        res = odd + even
    else:
        res = []
        fr = 0
        for i in odd_pos:
            if fr != i:
                if i - fr >= 3:
                    res += sorted(data[fr:i])
                else:
                    res += data[fr:i]
            res.append(data[i])
            fr = i + 1
        if data[-1] % 2 == 0:
            if len(data[fr:]) >= 3:
                res += sorted(data[fr:])
            else:
                res += data[fr:]
    return res


A = sort_data(A)
B = sort_data(B)
if A == B:
    print("Yes")
else:
    print("No")



n, m = map(int, input().split())
A = list(map(int, input().split()))
S = [input() for i in range(n)]
score = [i + 1 for i in range(n)]

B = [(i, j) for i, j in zip(range(m), A)]
B.sort(key=lambda x: x[1], reverse=True)
C = [i for i, j in B]
# print(C)

for i in range(n):
    for j in range(m):
        if S[i][j] == "o":
            score[i] += A[j]
# print(score)
ms = max(score)

for i in range(n):
    count = 0
    for j in range(m):
        if ms <= score[i]:
            break
        index = C[j]
        if S[i][j] != "o":
            score[i] += A[index]
            count += 1
    print(count)



import bisect
import copy
import decimal
import fractions
import heapq
import itertools
import math
import random
import sys
import time
from collections import Counter, deque, defaultdict
from functools import lru_cache, reduce
from heapq import heappush, heappop, heapify, heappushpop, _heappop_max, _heapify_max


def _heappush_max(heap, item):
    heap.append(item)
    heapq._siftdown_max(heap, 0, len(heap) - 1)


def _heappushpop_max(heap, item):
    if heap and item < heap[0]:
        item, heap[0] = heap[0], item
        heapq._siftup_max(heap, 0)
    return item


from math import gcd as GCD

read = sys.stdin.read
readline = sys.stdin.readline
readlines = sys.stdin.readlines
write = sys.stdout.write
# import pypyjit
# pypyjit.set_param('max_unroll_recursion=-1')
# sys.set_int_max_str_digits(10**9)


def Berlekamp_Massey(A):
    n = len(A)
    B, C = [1], [1]
    l, m, p = 0, 1, 1
    for i in range(n):
        d = A[i]
        for j in range(1, l + 1):
            d += C[j] * A[i - j]
            d %= mod
        if d == 0:
            m += 1
            continue
        T = C.copy()
        q = pow(p, mod - 2, mod) * d % mod
        if len(C) < len(B) + m:
            C += [0] * (len(B) + m - len(C))
        for j, b in enumerate(B):
            C[j + m] -= q * b
            C[j + m] %= mod
        if 2 * l <= i:
            B = T
            l, m, p = i + 1 - l, 1, d
        else:
            m += 1
    res = [-c % mod for c in C[1:]]
    return res


def BMBM(A, N, mod=0):
    deno = [1] + [-c for c in Berlekamp_Massey(A)]
    nume = [0] * (len(deno) - 1)
    for i in range(len(A)):
        for j in range(len(deno)):
            if i + j < len(nume):
                nume[i + j] += A[i] * deno[j]
                nume[i + j] %= mod
    return Bostan_Mori(nume, deno, N, mod=mod)


def Bostan_Mori(poly_nume, poly_deno, N, mod=0, convolve=None):
    # if type(poly_nume)==Polynomial:
    #    poly_nume=poly_nume.polynomial
    # if type(poly_deno)==Polynomial:
    #    poly_deno=poly_deno.polynomial
    if convolve == None:

        def convolve(poly_nume, poly_deno):
            conv = [0] * (len(poly_nume) + len(poly_deno) - 1)
            for i in range(len(poly_nume)):
                for j in range(len(poly_deno)):
                    x = poly_nume[i] * poly_deno[j]
                    if mod:
                        x %= mod
                    conv[i + j] += x
            if mod:
                for i in range(len(conv)):
                    conv[i] %= mod
            return conv

    while N:
        poly_deno_ = [-x if i % 2 else x for i, x in enumerate(poly_deno)]
        if N % 2:
            poly_nume = convolve(poly_nume, poly_deno_)[1::2]
        else:
            poly_nume = convolve(poly_nume, poly_deno_)[::2]
        poly_deno = convolve(poly_deno, poly_deno_)[::2]
        if mod:
            for i in range(len(poly_nume)):
                poly_nume[i] %= mod
            for i in range(len(poly_deno)):
                poly_deno[i] %= mod
        N //= 2
    return poly_nume[0]


N, M = map(int, input().split())
P = list(map(int, input().split()))
for i in range(N):
    P[i] -= 1
ans = 0
mod = 998244353
inve0 = pow(N * (N - 1) - 4 * (N - 2) - 2, mod - 2, mod)
inve1 = pow(4 * (N - 2), mod - 2, mod)


def f0(N, i, j):
    if N <= 3:
        return 0
    retu = N * (N + 1) * (N - 1) // 3
    retu -= (i * (i + 1) // 2 + (N - 1 - i) * (N - i) // 2 - abs(i - j)) * 2
    retu -= (j * (j + 1) // 2 + (N - 1 - j) * (N - j) // 2 - abs(i - j)) * 2
    retu -= abs(i - j) * 2
    return retu * inve0 % mod


def f1(N, i, j):
    if N <= 2:
        return 0
    retu = 0
    retu += (i * (i + 1) // 2 + (N - 1 - i) * (N - i) // 2 - abs(i - j)) * 2
    retu += (j * (j + 1) // 2 + (N - 1 - j) * (N - j) // 2 - abs(i - j)) * 2
    return retu * inve1 % mod


def f2(N, i, j):
    return abs(i - j)


cnt = [0] * 3
cnt[0] += N * (N - 1) // 2 - 4
cnt[1] += N - 3
cnt[0] += 2 * 2
cnt[1] += (N - 2) * (N - 3) // 2 + N - 2 + 1
cnt[2] += 2 * (N - 2)
cnt[1] += 1
cnt[2] += (N - 2) * (N - 3) // 2 + 1

dp = [0, 0, 1]
lst = []
for m in range(5):
    lst.append(
        sum(
            (
                f0(N, P[i], P[i + 1]) * dp[0]
                + f1(N, P[i], P[i + 1]) * dp[1]
                + f2(N, P[i], P[i + 1]) * dp[2]
            )
            % mod
            for i in range(N - 1)
        )
    )
    prev = dp
    dp = [0] * 3
    dp[0] += prev[0] * (N * (N - 1) // 2 - 4)
    dp[0] += prev[1] * (N - 3)
    dp[1] += prev[0] * 2 * 2
    dp[1] += prev[1] * ((N - 2) * (N - 3) // 2 + N - 2 + 1)
    dp[1] += prev[2] * 2 * (N - 2)
    dp[2] += prev[1] * 1
    dp[2] += prev[2] * ((N - 2) * (N - 3) // 2 + 1)
    for c in range(3):
        dp[c] %= mod
ans += BMBM(lst, M, mod)
ans %= mod
print(ans)



"""Tests for compact output formats."""

from __future__ import annotations

import json
from pathlib import Path
from typing import cast

import pytest

from llmdebug import SnapshotConfig, debug_snapshot, get_latest_snapshot
from llmdebug.compact_keys import (
    KEY_MAP,
    REVERSE_KEY_MAP,
    compact_keys,
    expand_keys,
    is_compact_snapshot,
)
from llmdebug.config import OutputFormat
from llmdebug.output import write_bundle


# Check if toons is available
def _has_toons() -> bool:
    try:
        import toons  # pyright: ignore[reportMissingImports]

        return True
    except ImportError:
        return False


class TestCompactKeys:
    """Tests for key compaction/expansion."""

    def test_key_map_is_bijective(self):
        """Verify KEY_MAP has no duplicate values."""
        assert len(KEY_MAP) == len(set(KEY_MAP.values())), "KEY_MAP has duplicate short keys"

    def test_reverse_map_matches(self):
        """Verify REVERSE_KEY_MAP is correct inverse."""
        for full, short in KEY_MAP.items():
            assert REVERSE_KEY_MAP[short] == full

    def test_compact_keys_simple_dict(self):
        """Test key compaction on simple dict."""
        data = {"schema_version": 1, "timestamp_utc": "2024-01-01"}
        result = compact_keys(data)
        assert result == {"_v": 1, "_ts": "2024-01-01"}

    def test_compact_keys_nested_dict(self):
        """Test key compaction on nested dict."""
        data = {
            "exception": {
                "type": "ValueError",
                "message": "test error",
            }
        }
        result = compact_keys(data)
        assert result == {
            "_exc": {
                "_t": "ValueError",
                "_msg": "test error",
            }
        }

    def test_compact_keys_with_list(self):
        """Test key compaction on dict containing list."""
        data = {
            "frames": [
                {"file": "/test.py", "line": 10},
                {"file": "/other.py", "line": 20},
            ]
        }
        result = compact_keys(data)
        assert result == {
            "_fr": [
                {"_f": "/test.py", "_l": 10},
                {"_f": "/other.py", "_l": 20},
            ]
        }

    def test_compact_keys_preserves_unknown_keys(self):
        """Test that unknown keys are preserved as-is."""
        data = {"unknown_key": "value", "type": "test"}
        result = compact_keys(data)
        assert result == {"unknown_key": "value", "_t": "test"}

    def test_expand_keys_reverses_compact(self):
        """Test that expand_keys reverses compact_keys."""
        original = {
            "schema_version": 1,
            "frames": [
                {"file": "/test.py", "locals": {"x": 1}},
            ],
            "exception": {"type": "Error", "message": "msg"},
        }
        compacted = compact_keys(original)
        expanded = expand_keys(compacted)
        assert expanded == original

    def test_is_compact_snapshot_detects_compact(self):
        """Test compact snapshot detection."""
        compact = {"_v": 1, "_fr": [], "_exc": {}, "_ts": "2024"}
        assert is_compact_snapshot(compact) is True

    def test_is_compact_snapshot_detects_full(self):
        """Test full snapshot detection."""
        full = {"schema_version": 1, "frames": [], "exception": {}}
        assert is_compact_snapshot(full) is False

    def test_is_compact_snapshot_detects_marker(self):
        """Test explicit compact marker detection."""
        assert is_compact_snapshot({"__llmdebug_compact__": 1}) is True

    def test_is_compact_snapshot_ignores_short_key_false_positive(self):
        """Single short-like keys in normal JSON should not imply compact mode."""
        assert is_compact_snapshot({"_v": "user_value"}) is False

    def test_compact_keys_preserves_user_data(self):
        """Test that user variable names in locals/args are not transformed."""
        data: dict[str, list[dict[str, object]]] = {
            "frames": [
                {
                    "file": "/test.py",
                    "locals": {"a": 1, "type": "test", "message": "hello"},
                    "args": {"x": 10, "type": "arg_type"},
                }
            ]
        }
        result = compact_keys(data)
        assert isinstance(result, dict)
        # Frame keys should be compacted
        assert "_fr" in result
        frames = result["_fr"]
        assert isinstance(frames, list) and len(frames) > 0
        frame = frames[0]
        assert isinstance(frame, dict)
        assert "_f" in frame
        assert "_loc" in frame
        # But locals content should preserve user variable names
        assert frame["_loc"] == {"a": 1, "type": "test", "message": "hello"}
        assert frame["_args"] == {"x": 10, "type": "arg_type"}

    def test_expand_keys_preserves_user_data(self):
        """Test that expansion preserves user variable names."""
        data: dict[str, list[dict[str, object]]] = {
            "_fr": [
                {
                    "_f": "/test.py",
                    "_loc": {"a": 1, "_t": "should_stay", "type": "user_var"},
                    "_args": {"b": 2, "_msg": "also_stay"},
                }
            ]
        }
        result = expand_keys(data)
        assert isinstance(result, dict)
        # Frame keys should be expanded
        assert "frames" in result
        frames = result["frames"]
        assert isinstance(frames, list) and len(frames) > 0
        frame = frames[0]
        assert isinstance(frame, dict)
        assert "file" in frame
        assert "locals" in frame
        # But locals content should be unchanged (user data)
        assert frame["locals"] == {"a": 1, "_t": "should_stay", "type": "user_var"}
        assert frame["args"] == {"b": 2, "_msg": "also_stay"}

    def test_enhanced_pytest_context_roundtrip(self):
        """Test compact/expand round-trip for all 6 enhanced pytest context types."""
        original = {
            "schema_version": 1,
            "frames": [],
            "exception": {"type": "AssertionError", "message": "test"},
            "pytest": {
                "nodeid": "test_it.py::test_example",
                "outcome": "failed",
                "when": "call",
                "fixtures": {
                    "data": "[1, 2, 3]",
                    "db_conn": "<Connection host='localhost'>",
                },
                "markers": {
                    "slow": {},
                    "skipif": {"args": ["sys.platform == 'win32'"]},
                },
                "timeout_config": {
                    "seconds": 30,
                    "kwargs": {"method": "'signal'"},
                },
                "param_indices": {"x": 1, "y": 0},
                "xdist_worker": "gw0",
                "rerun_count": 3,
                "flaky": True,
                "params": {"x": "20"},
                "repro": ["python", "-m", "pytest", "test_it.py::test_example", "-q"],
            },
        }
        compacted = compact_keys(original)
        expanded = expand_keys(compacted)
        assert expanded == original

    def test_compact_keys_preserves_locals_meta(self):
        """Test that locals_meta keys are treated as user data."""
        data = {
            "frames": [
                {
                    "file": "/test.py",
                    "locals_meta": {
                        # Variable name "type" should not be compacted to "_t"
                        "type": {"type": "builtins.str"},
                        "message": {"type": "builtins.str"},
                    },
                }
            ]
        }
        compacted = compact_keys(data)
        expanded = expand_keys(compacted)
        assert expanded == data


class TestCompactJSONOutput:
    """Tests for compact JSON output format."""

    def test_compact_json_is_valid_json(self, tmp_path: Path):
        """Test that compact JSON output is valid JSON."""
        cfg = SnapshotConfig(out_dir=str(tmp_path), output_format="json_compact")
        payload = {
            "name": "test",
            "schema_version": 1,
            "frames": [{"file": "/test.py", "line": 1}],
            "exception": {"type": "Error"},
        }
        path = write_bundle(payload, cfg)
        content = path.read_text()
        # Should parse as valid JSON
        parsed = json.loads(content)
        assert "_v" in parsed  # Uses short keys with underscore prefix

    def test_compact_json_smaller_than_pretty(self, tmp_path: Path):
        """Test that compact JSON is smaller than pretty JSON."""
        payload = {
            "name": "test",
            "schema_version": 1,
            "timestamp_utc": "2024-01-01T00:00:00Z",
            "frames": [{"file": "/test.py", "line": i, "function": f"func_{i}"} for i in range(5)],
            "exception": {"type": "ValueError", "message": "test error"},
        }

        # Write pretty JSON
        pretty_cfg = SnapshotConfig(out_dir=str(tmp_path / "pretty"), output_format="json")
        pretty_path = write_bundle(payload, pretty_cfg)
        pretty_size = pretty_path.stat().st_size

        # Write compact JSON
        compact_dir = str(tmp_path / "compact")
        compact_cfg = SnapshotConfig(out_dir=compact_dir, output_format="json_compact")
        compact_path = write_bundle(payload, compact_cfg)
        compact_size = compact_path.stat().st_size

        # Compact should be at least 20% smaller
        assert compact_size < pretty_size * 0.8, (
            f"Compact ({compact_size}) should be <80% of pretty ({pretty_size})"
        )

    def test_get_latest_auto_expands_compact(self, tmp_path: Path):
        """Test that get_latest_snapshot auto-expands compact keys."""
        cfg = SnapshotConfig(out_dir=str(tmp_path), output_format="json_compact")
        payload = {
            "name": "test",
            "schema_version": 1,
            "frames": [{"file": "/test.py", "line": 1}],
            "exception": {"type": "Error", "message": "test"},
        }
        write_bundle(payload, cfg)

        # Read back should have full keys
        snapshot = get_latest_snapshot(str(tmp_path))
        assert snapshot is not None
        assert "schema_version" in snapshot
        assert "frames" in snapshot
        assert "exception" in snapshot
        assert snapshot["frames"][0]["file"] == "/test.py"
        assert "__llmdebug_compact__" not in snapshot

    def test_get_latest_does_not_expand_plain_json_with_short_keys(self, tmp_path: Path):
        """Plain JSON with user key names like _v should remain unchanged."""
        cfg = SnapshotConfig(out_dir=str(tmp_path), output_format="json")
        payload = {
            "name": "test",
            "schema_version": 1,
            "frames": [],
            "exception": {},
            "_v": "user_value",
        }
        write_bundle(payload, cfg)

        snapshot = get_latest_snapshot(str(tmp_path))
        assert snapshot is not None
        assert snapshot["schema_version"] == 1
        assert snapshot["_v"] == "user_value"

    def test_output_format_validation(self):
        """Test that invalid output_format raises ValueError."""
        with pytest.raises(ValueError, match="output_format must be"):
            SnapshotConfig(output_format=cast(OutputFormat, "invalid"))


class TestDecoratorWithCompactFormat:
    """Test decorator with compact output format."""

    def test_debug_snapshot_with_compact_format(self, tmp_path: Path):
        """Test @debug_snapshot with json_compact format."""

        @debug_snapshot(out_dir=str(tmp_path), output_format="json_compact")
        def failing_func():
            raise ValueError("test error")

        with pytest.raises(ValueError):
            failing_func()

        # Verify snapshot exists and is compact
        snapshot = get_latest_snapshot(str(tmp_path))
        assert snapshot is not None
        assert snapshot["exception"]["type"] == "ValueError"

    def test_debug_snapshot_default_is_compact(self, tmp_path: Path):
        """Test that default output format is json_compact."""

        @debug_snapshot(out_dir=str(tmp_path))
        def failing_func():
            raise ValueError("test")

        with pytest.raises(ValueError):
            failing_func()

        # Read raw file to verify it's compact
        latest = tmp_path / "latest.json"
        raw = json.loads(latest.read_text())
        assert "_v" in raw or "_exc" in raw  # Uses short keys with underscore prefix


@pytest.mark.skipif(not _has_toons(), reason="toons package not installed")
class TestTOONFormat:
    """Tests for TOON output format (requires toons package)."""

    def test_toon_format_writes_toon_file(self, tmp_path: Path):
        """Test that TOON format writes .toon file."""
        cfg = SnapshotConfig(out_dir=str(tmp_path), output_format="toon")
        payload = {
            "name": "test",
            "schema_version": 1,
            "frames": [{"file": "/test.py", "line": 1}],
        }
        path = write_bundle(payload, cfg)
        assert path.suffix == ".toon"
        assert (tmp_path / "latest.toon").exists()

    def test_toon_format_roundtrip(self, tmp_path: Path):
        """Test TOON encoding/decoding roundtrip."""
        cfg = SnapshotConfig(out_dir=str(tmp_path), output_format="toon")
        payload = {
            "name": "test",
            "schema_version": 1,
            "frames": [{"file": "/test.py", "line": i, "function": f"f{i}"} for i in range(3)],
            "exception": {"type": "Error", "message": "test"},
        }
        write_bundle(payload, cfg)

        snapshot = get_latest_snapshot(str(tmp_path))
        assert snapshot is not None
        assert snapshot["schema_version"] == 1
        assert len(snapshot["frames"]) == 3

    def test_get_latest_prefers_newest_when_both_exist(self, tmp_path: Path):
        """If both latest.json and latest.toon exist, prefer newest by mtime."""
        import os

        # Write a TOON snapshot (this creates latest.toon).
        toon_cfg = SnapshotConfig(out_dir=str(tmp_path), output_format="toon")
        payload = {"name": "toon_wins", "schema_version": 1, "frames": []}
        write_bundle(payload, toon_cfg)

        latest_toon = tmp_path / "latest.toon"
        assert latest_toon.exists()

        # Create a stale latest.json with older mtime.
        (tmp_path / "latest.json").write_text(json.dumps({"name": "stale_json"}))
        old = latest_toon.stat().st_mtime - 10
        os.utime(tmp_path / "latest.json", (old, old))

        snapshot = get_latest_snapshot(str(tmp_path))
        assert snapshot is not None
        assert snapshot["name"] == "toon_wins"

    def test_toon_smaller_than_json(self, tmp_path: Path):
        """Test TOON format is smaller than pretty JSON."""
        payload = {
            "name": "test",
            "schema_version": 1,
            "frames": [
                {"file": f"/path/to/file{i}.py", "line": i, "function": f"function_{i}"}
                for i in range(10)
            ],
            "exception": {"type": "ValueError", "message": "test error message"},
        }

        # Write pretty JSON
        json_cfg = SnapshotConfig(out_dir=str(tmp_path / "json"), output_format="json")
        json_path = write_bundle(payload, json_cfg)
        json_size = json_path.stat().st_size

        # Write TOON
        toon_cfg = SnapshotConfig(out_dir=str(tmp_path / "toon"), output_format="toon")
        toon_path = write_bundle(payload, toon_cfg)
        toon_size = toon_path.stat().st_size

        # TOON should be smaller (allow for small payloads where overhead matters)
        # For larger payloads, savings should be more significant
        assert toon_size <= json_size, f"TOON ({toon_size}) should be <= JSON ({json_size})"


class TestMixedFormatCleanup:
    """Test snapshot cleanup works with mixed formats."""

    def test_cleanup_handles_mixed_formats(self, tmp_path: Path):
        """Test cleanup considers both .json and .toon files."""
        # Create some JSON files manually
        for i in range(3):
            (tmp_path / f"2024010{i}T000000Z_test.json").write_text("{}")

        # Write one more with low max_snapshots
        cfg = SnapshotConfig(
            out_dir=str(tmp_path),
            output_format="json_compact",
            max_snapshots=2,
        )
        payload = {"name": "test", "schema_version": 1}
        write_bundle(payload, cfg)

        # Should only have 2 snapshots left (plus latest.json)
        json_files = [f for f in tmp_path.glob("*.json") if not f.name.startswith("latest")]
        assert len(json_files) == 2



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.palindromePairs(["abcd", "dcba", "lls", "s", "sssll"])
    assert result == [[0, 1], [1, 0], [3, 2], [2, 4]]


def test_case_1():
    sol = Solution()
    result = sol.palindromePairs(["bat", "tab", "cat"])
    assert result == [[0, 1], [1, 0]]


def test_case_2():
    sol = Solution()
    result = sol.palindromePairs(["a", ""])
    assert result == [[0, 1], [1, 0]]



from itertools import permutations
from sys import stdin


class FastIO:
    def __init__(self):
        self.random_seed = 0
        self.flush = False
        self.inf = 1 << 32
        return

    @staticmethod
    def read_int():
        return int(stdin.readline().rstrip())

    @staticmethod
    def read_float():
        return float(stdin.readline().rstrip())

    @staticmethod
    def read_list_ints():
        return list(map(int, stdin.readline().rstrip().split()))

    @staticmethod
    def read_list_ints_minus_one():
        return list(map(lambda x: int(x) - 1, stdin.readline().rstrip().split()))

    @staticmethod
    def read_str():
        return stdin.readline().rstrip()

    @staticmethod
    def read_list_strs():
        return stdin.readline().rstrip().split()

    def get_random_seed(self):
        import random

        self.random_seed = random.randint(0, 10**9 + 7)
        return

    def st(self, x):
        return print(x, flush=self.flush)

    def yes(self, s=None):
        self.st("Yes" if not s else s)
        return

    def no(self, s=None):
        self.st("No" if not s else s)
        return

    def lst(self, x):
        return print(*x, flush=self.flush)

    def flatten(self, lst):
        self.st("\n".join(str(x) for x in lst))
        return

    @staticmethod
    def max(a, b):
        return a if a > b else b

    @staticmethod
    def min(a, b):
        return a if a < b else b

    @staticmethod
    def ceil(a, b):
        return a // b + int(a % b != 0)

    @staticmethod
    def accumulate(nums):
        n = len(nums)
        pre = [0] * (n + 1)
        for i in range(n):
            pre[i + 1] = pre[i] + nums[i]
        return pre


class Solution:
    def __init__(self):
        return

    @staticmethod
    def main(ac=FastIO()):
        """
        url: url of the problem
        tag: algorithm tag
        """

        def ceil(xxx, yyy):
            return xxx / yyy + int(xxx % yyy != 0)

        x, y, a, b, c = ac.read_list_ints()
        for perm in permutations([a, b, c], 3):
            aa, bb, cc = perm
            yy = ceil(aa, x)
            rest = y - yy
            if rest > 0 and ceil(bb, rest) + ceil(cc, rest) <= x:
                ac.yes()
                return

            if ceil(aa, x) + ceil(bb, x) + ceil(cc, x) <= y:
                ac.yes()
                return

            if ceil(aa, y) + ceil(bb, y) + ceil(cc, y) <= x:
                ac.yes()
                return

            xx = ceil(aa, y)
            rest = x - xx
            if rest > 0 and ceil(bb, rest) + ceil(cc, rest) <= y:
                ac.yes()
                return
        ac.no()
        return


Solution().main()



n, w = map(int, input().split())
a = list(map(int, input().split()))
sum_set = set(a)

# 2個の和
for i in range(0, n - 1):
    for j in range(i + 1, n):
        s = a[i] + a[j]
        if s <= w:
            sum_set.add(s)

# 3個の和
for i in range(0, n - 2):
    for j in range(i + 1, n - 1):
        for k in range(j + 1, n):
            s = a[i] + a[j] + a[k]
            if s <= w:
                sum_set.add(s)

cnt = 0
for i in range(w):
    if i in sum_set:
        cnt += 1

print(cnt)



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5\n3 1 4 5 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2\n2 4\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='20\n9 7 19 7 10 4 13 9 4 8 10 15 16 3 18 19 12 13 2 12\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '10\n1 2 5 6 8 11 14 17 18 20\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n2 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



"""Auto-correct expected_exception in case.json based on actual test output.

Many imported cases predict the wrong exception type (e.g., AssertionError when
the actual error is NameError). This script runs each case's baseline test,
captures the actual exception, updates case.json, and verifies the oracle patch
still fixes it.

Usage::

    PYTHONPATH=. uv run python evals/importers/fixup_expected_exceptions.py [--bug-source debugbench]
"""

from __future__ import annotations

import argparse
import json
import shutil
import tempfile
from pathlib import Path

from evals.run_eval import (
    _REPO_ROOT,
    Condition,
    apply_diff,
    load_cases,
    run_pytest,
)
from evals.validate_cases import (
    expected_exception_in_output,
    extract_exception_candidates,
)


def fixup_cases(
    cases_dir: Path,
    *,
    bug_source: str | None = None,
    timeout_sec: int = 30,
    output_format: str = "json_compact",
) -> dict[str, str]:
    """Auto-correct expected_exception for cases that fail only on exception mismatch.

    Returns dict mapping case_id -> status.
    """
    cases = load_cases(cases_dir)
    results: dict[str, str] = {}

    for spec in cases:
        case_id = spec.case_id
        case_path = spec.path

        # Filter by bug_source if specified.
        if bug_source and spec.bug_source != bug_source:
            continue

        # Read full case.json for modification.
        meta = json.loads((case_path / "case.json").read_text(encoding="utf-8"))
        expected_exc = spec.expected_exception
        python_args = spec.python_args
        case_timeout = spec.timeout_sec

        with tempfile.TemporaryDirectory(prefix=f"llmdebug-fixup-{case_id}-") as tmp:
            workdir = Path(tmp)
            shutil.copytree(
                case_path,
                workdir,
                dirs_exist_ok=True,
                ignore=shutil.ignore_patterns("__pycache__", "*.pyc", "*.pyo"),
            )

            # Run baseline.
            baseline = run_pytest(
                workdir, python_args, Condition.TRACEBACK_ONLY, case_timeout, output_format
            )

            if baseline.timed_out:
                results[case_id] = "skip: timed out"
                continue

            if baseline.returncode == 0:
                results[case_id] = "skip: baseline passed"
                continue

            combined = (baseline.stdout or "") + "\n" + (baseline.stderr or "")

            # Check if current expected_exception is already correct.
            if expected_exception_in_output(expected_exc, combined):
                # Already correct — verify oracle patch works.
                patch_text = (case_path / "oracle.patch").read_text(encoding="utf-8")
                applied, _ = apply_diff(workdir, patch_text)
                if applied:
                    patched = run_pytest(
                        workdir,
                        python_args,
                        Condition.TRACEBACK_ONLY,
                        case_timeout,
                        output_format,
                    )
                    if patched.returncode == 0:
                        results[case_id] = "ok: already correct"
                        continue
                    results[case_id] = "skip: oracle didn't fix"
                    continue
                results[case_id] = "skip: oracle patch failed"
                continue

            # Find actual exception.
            candidates = extract_exception_candidates(combined)
            if not candidates:
                results[case_id] = "skip: no exception found"
                continue

            actual_exc = candidates[0]  # First (most likely) candidate

            # Verify oracle patch fixes the issue with the new exception.
            patch_text = (case_path / "oracle.patch").read_text(encoding="utf-8")
            applied, _ = apply_diff(workdir, patch_text)
            if not applied:
                results[case_id] = "skip: oracle patch failed"
                continue

            patched = run_pytest(
                workdir, python_args, Condition.TRACEBACK_ONLY, case_timeout, output_format
            )
            if patched.returncode != 0:
                results[case_id] = "skip: oracle didn't fix"
                continue

            # Update case.json with corrected expected_exception.
            meta["expected_exception"] = actual_exc
            (case_path / "case.json").write_text(
                json.dumps(meta, indent=2, ensure_ascii=False) + "\n",
                encoding="utf-8",
            )
            results[case_id] = f"fixed: {expected_exc} -> {actual_exc}"
            print(f"  [fixed] {case_id}: {expected_exc} -> {actual_exc}")

    return results


def main() -> None:
    parser = argparse.ArgumentParser(description="Auto-correct expected_exception in case.json.")
    parser.add_argument("--cases-dir", default="evals/cases")
    parser.add_argument("--bug-source", default=None)
    args = parser.parse_args()

    cases_dir = Path(args.cases_dir)
    if not cases_dir.is_absolute():
        cases_dir = _REPO_ROOT / cases_dir

    results = fixup_cases(cases_dir, bug_source=args.bug_source)

    fixed = sum(1 for v in results.values() if v.startswith("fixed"))
    ok = sum(1 for v in results.values() if v.startswith("ok"))
    skipped = sum(1 for v in results.values() if v.startswith("skip"))

    print(f"\nResults: {fixed} fixed, {ok} already correct, {skipped} skipped")

    # Delete cases that were skipped (unfixable).
    deleted = 0
    cases_dir_path = Path(args.cases_dir)
    if not cases_dir_path.is_absolute():
        cases_dir_path = _REPO_ROOT / cases_dir_path
    for case_id, status in results.items():
        if status.startswith("skip"):
            case_dir = cases_dir_path / case_id
            if case_dir.exists():
                shutil.rmtree(case_dir, ignore_errors=True)
                deleted += 1

    if deleted:
        print(f"Deleted {deleted} unfixable cases.")


if __name__ == "__main__":
    main()



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n800 300\n100 100\n200 10\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '5\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n800 300\n100 0\n0 10\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '38\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n800 300\n801 300\n800 301\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '0\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10\n1000000 1000000 1000000 1000000 1000000 1000000 1000000 1000000 1000000 1000000\n0 1 2 3 4 5 6 7 8 9\n9 8 7 6 5 4 3 2 1 0\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '222222\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1\n1\n1\n1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



# D - Unicyclic Components
from collections import defaultdict


def main():
    N, M = map(int, input().split())
    lib = UnionFind(N)
    vertexes = set()
    cnt = defaultdict(int)

    for _ in range(M):
        u, v = map(int, input().split())
        lib.unite(u, v)
        vertexes.add(u)
        vertexes.add(v)
        cnt[u] += 1
        cnt[v] += 1

    groups = lib.get_groups(vertexes)
    matches = True

    for group in groups:
        n = len(group)
        m = 0

        for v in group:
            m += cnt[v]

        if n != m // 2:
            matches = False

    if matches:
        print("Yes")
    else:
        print("No")


class UnionFind:
    def __init__(self, n):
        # n で頂点数を受け取る
        # 頂点番号が連番ではない場合、最大の頂点番号を渡してもOK
        # 頂点番号は1から始まることが多いので、n頂点の場合、n+1でリストを作成しておく

        # [summary]インスタンス変数を宣言

        # 各頂点の親の番号(自身が根の場合は -1)
        # 最初は、どの頂点も根であるとして初期化
        self.par = [-1] * (n + 1)

        # 各頂点の属するグループの頂点数
        self.size = [1] * (n + 1)

        # 頂点をグループ分けするときに使う
        self.groups = dict()

        # サイクル(閉路)を検出するためのフラグ
        self.cycled = False

    def root(self, x):
        # [summary]根を求める
        # その過程で、経路圧縮を行う(par[x]には、根が格納される)

        if self.par[x] == -1:
            # xが根の場合は、直接xを返す
            return x
        else:
            # xの親par[x]を根に張り替える
            # (ここで代入しておくことで、後の繰り返しを避けられる)
            # 各頂点の親子関係を知りたい場合は、この行をコメントアウト
            self.par[x] = self.root(self.par[x])

            return self.root(self.par[x])

    def is_same(self, x, y):
        # [summary]xとyが同じグループに属するかどうか

        if self.root(x) == self.root(y):
            return True

    def unite(self, x, y):
        # [summary]xを含むグループと yを含むグループを併合する

        # x,yを それぞれ根まで移動する
        x = self.root(x)
        y = self.root(y)

        if x == y:
            # すでに同じグループのときは 何もしない
            # すでに同じグループに属しているのに
            # また辺をつないだら、閉路が発生する
            # (実装上は、実際に辺をつなぐ訳ではなく
            # フラグをオンにするだけ)
            self.cycled = True
        else:
            # union by size(y側のサイズが小さくなるようにする)
            if self.size[x] < self.size[y]:
                x, y = y, x

            # yをxの子にする
            self.par[y] = x
            self.size[x] += self.size[y]

    def detects_cycle(self):
        return self.cycled

    def get_size(self, x):
        # [summary]xを含むグループの頂点数

        return self.size[self.root(x)]

    def get_groups(self, vertexes):
        # [summary]各頂点をグループ分けして、"[1,2,4], [3,5]"のような
        # グループ分けされた頂点番号の集合を返す

        self.__break_into_groups(vertexes)

        return self.groups.values()

    def __break_into_groups(self, vertexes):
        # [summary]各頂点をグループ分けする

        for v in vertexes:
            r = self.root(v)

            if not r in self.groups.keys():
                self.groups[r] = [v]
            else:
                self.groups[r].append(v)


if __name__ == "__main__":
    main()



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def gridGame(self, grid: List[List[int]]) -> int:
        result = float("inf")
        left, right = 0, sum(grid[0])

        for a, b in zip(grid[1], grid[0]):
            right -= a

            result = min(result, max(left, right))
            left += b

        return result



def calc_area(y, x):
    ret = score[N][N] * (x // N) * (y // N)
    ret += score[N][x % N] * (y // N)
    ret += score[y % N][N] * (x // N)
    ret += score[y % N][x % N]
    return ret


N, Q = map(int, input().split())
P = [list(input()) for i in range(N)]
score = [[0] * (N + 1) for i in range(N + 1)]
ABCD = [list(map(int, input().split())) for i in range(Q)]

for i in range(1, N + 1):
    for j in range(1, N + 1):
        if P[i - 1][j - 1] == "B":
            score[i][j] = 1

for i in range(N + 1):
    for j in range(1, N + 1):
        score[i][j] += score[i][j - 1]

for j in range(N + 1):
    for i in range(1, N + 1):
        score[i][j] += score[i - 1][j]

for i in score:
    print(*i)

for a, b, c, d in ABCD:
    c += 1
    d += 1
    print(calc_area(c, d) - calc_area(a, d) - calc_area(c, b) + calc_area(a, b))



from collections import deque


class Trie_with_Aho_Corasick:
    def __init__(self, keywords, sigma=26):
        self.keywords = keywords
        self.sigma = sigma
        self.tree = [[-1] * (sigma + 2) for _ in range(sum(len(_str) for _str in keywords) + 1)]
        self.depth = [0] * len(self.tree)
        self.num = 1
        ### _build_trie ###
        for i, word in enumerate(keywords):
            self._register(i, word)
        self.init_failure()

    def _register(self, i, word):
        pos = 0
        for c in word:
            c = ord(c) - ord_a
            if self.tree[pos][c] == -1:
                self.tree[pos][c] = self.num
                self.depth[self.num] = self.depth[pos] + 1
                self.num += 1
            pos = self.tree[pos][c]
        self.tree[pos][-1] = i

    def init_failure(self):
        self.tree[0][-2] = 0
        que = deque([0])
        while que:
            v = que.popleft()
            f = self.tree[v][-2]
            if self.tree[v][-1] == -1:
                self.tree[v][-1] = self.tree[f][-1]
            for i in range(self.sigma):
                if self.tree[v][i] == -1:
                    f = self.tree[v][-2]
                    if self.tree[f][i] == -1:
                        self.tree[v][i] = 0
                    else:
                        self.tree[v][i] = self.tree[f][i]
                else:
                    c = self.tree[v][i]
                    f = self.tree[v][-2]
                    if self.tree[f][i] == c:
                        self.tree[c][-2] = 0
                    else:
                        self.tree[c][-2] = self.tree[f][i]
                    que.append(c)

    def match(self, s):
        res = [0] * len(s)
        pos = 0
        for i in range(len(s)):
            c = ord(s[i]) - ord_a
            res[i] = pos = self.tree[pos][c]
        return res


s = str(input())
n = int(input())
t = [str(input()) for _ in range(n)]

ord_a = ord("a")
aho = Trie_with_Aho_Corasick(t)
ans = 0
m = [aho.tree[i][-1] for i in aho.match(s)]
l = -1
for i in range(len(s)):
    if m[i] == -1:
        continue
    x = len(t[m[i]])
    if l < i - x + 1:
        l = i
        ans += 1
print(ans)



from collections import defaultdict, deque, Counter
from heapq import heappush, heappop, heapify
import math
import bisect
import random
from itertools import permutations, accumulate, combinations, product
import sys
import string
from bisect import bisect_left, bisect_right
from math import factorial, ceil, floor
from operator import mul
from functools import reduce


sys.setrecursionlimit(2147483647)
INF = 10**10


def LI():
    return list(map(int, sys.stdin.readline().split()))


def I():
    return int(sys.stdin.readline())


def LS():
    return sys.stdin.buffer.readline().rstrip().decode("utf-8").split()


def S():
    return sys.stdin.buffer.readline().rstrip().decode("utf-8")


def IR(n):
    return [I() for i in range(n)]


def LIR(n):
    return [LI() for i in range(n)]


def SR(n):
    return [S() for i in range(n)]


def LSR(n):
    return [LS() for i in range(n)]


def SRL(n):
    return [list(S()) for i in range(n)]


def MSRL(n):
    return [[int(j) for j in list(S())] for i in range(n)]


mod = 998244353


class UnionFind:
    def __init__(self, n):
        # 負  : 根であることを示す。絶対値はランクを示す
        # 非負: 根でないことを示す。値は親を示す
        self.table = [-1] * n
        self.size = [1] * n
        self.group_num = n

    def root(self, x):
        if self.table[x] < 0:
            return x
        else:
            self.table[x] = self.root(self.table[x])
            return self.table[x]

    def get_size(self, x):
        r = self.root(x)
        return self.size[r]

    def is_same(self, x, y):
        return self.root(x) == self.root(y)

    def union(self, x, y):
        r1 = self.root(x)
        r2 = self.root(y)
        if r1 == r2:
            return
        # ランクの取得
        d1 = self.table[r1]
        d2 = self.table[r2]
        if d1 <= d2:
            self.table[r2] = r1
            self.size[r1] += self.size[r2]
            if d1 == d2:
                self.table[r1] -= 1
        else:
            self.table[r1] = r2
            self.size[r2] += self.size[r1]
        self.group_num -= 1


n = I()
A = LI()
B = LI()
U = UnionFind(n)
if sorted(A) != sorted(B):
    print("No")
    exit()

if len(set(A)) != A:
    print("Yes")
    exit()

for i in range(n):
    U.union(A[i] - 1, B[i] - 1)

vis = [0] * n
L = []
for g in range(n):
    if vis[U.root(g)] == 0:
        vis[U.root(g)] = 1
        L += [U.get_size(g)]

LL = []
for s in L:
    if s == 1:
        continue
    elif s > 2:
        if (s - 1) % 2:
            LL += [1]
    else:
        LL += [1]


if not LL or sum(LL) % 2 == 0:
    print("Yes")
else:
    print("No")



N = int(input())
AC = sorted(sorted([list(map(int, input().split())) for _ in range(N)]), key=lambda x: x[1])
num, _min = AC[0]
for i in AC[1:]:
    if num != i[1]:
        num = i[1]
        if _min < i[0]:
            _min = i[0]
print(_min)



"""Tests for async context capture."""

import asyncio

import pytest

from llmdebug.async_context import get_async_context, is_coroutine_frame


def test_async_context_not_in_async():
    """Test that async context returns None when not in async context."""
    result = get_async_context()
    assert result is None


@pytest.mark.asyncio(loop_scope="function")
async def test_async_context_in_async():
    """Test async context capture when running in async context."""
    result = get_async_context()

    assert result is not None
    assert "current_task" in result
    assert "total_tasks" in result
    assert result["total_tasks"] >= 1


@pytest.mark.asyncio(loop_scope="function")
async def test_async_context_with_multiple_tasks():
    """Test async context with multiple concurrent tasks."""
    results = []

    async def capture_task():
        await asyncio.sleep(0.01)
        results.append(get_async_context())

    async def background_task():
        await asyncio.sleep(0.1)

    # Create background tasks
    bg_tasks = [asyncio.create_task(background_task(), name=f"bg_task_{i}") for i in range(3)]

    # Create a task that captures context
    capture = asyncio.create_task(capture_task(), name="capture_task")
    await capture

    # Cancel background tasks
    for task in bg_tasks:
        task.cancel()
        try:
            await task
        except asyncio.CancelledError:
            pass

    assert len(results) == 1
    context = results[0]
    assert context is not None
    assert context["current_task"] == "capture_task"
    assert context["total_tasks"] >= 4  # 3 bg + 1 capture


@pytest.mark.asyncio(loop_scope="function")
async def test_async_context_current_coro():
    """Test that current coroutine name is captured."""

    async def my_named_coroutine():
        return get_async_context()

    task = asyncio.create_task(my_named_coroutine())
    context = await task

    assert context is not None
    # The coroutine name should be captured
    assert "current_coro" in context or "current_task" in context


def test_is_coroutine_frame_with_regular_function():
    """Test is_coroutine_frame returns False for regular frames."""
    import sys

    # Get current frame (not a coroutine)
    frame = sys._getframe()
    assert is_coroutine_frame(frame) is False


@pytest.mark.asyncio(loop_scope="function")
async def test_is_coroutine_frame_with_async_function():
    """Test is_coroutine_frame for async function frames."""
    import sys

    # This frame should be a coroutine frame
    frame = sys._getframe()

    # The test itself runs in async context, so the frame should have CO_COROUTINE
    # Note: The actual frame might be the test runner frame, not the coroutine itself
    # This tests the basic functionality
    result = is_coroutine_frame(frame)
    # Just verify it doesn't crash and returns a bool
    assert isinstance(result, bool)


def test_async_context_other_tasks_truncation():
    """Test that other_tasks list is truncated to max 10."""

    async def run_test():
        tasks = []
        for i in range(15):
            task = asyncio.create_task(asyncio.sleep(0.5), name=f"task_{i}")
            tasks.append(task)

        await asyncio.sleep(0.01)  # Let tasks start
        context = get_async_context()

        # Cancel all tasks
        for task in tasks:
            task.cancel()
            try:
                await task
            except asyncio.CancelledError:
                pass

        return context

    context = asyncio.run(run_test())

    assert context is not None
    if "other_tasks" in context:
        assert len(context["other_tasks"]) <= 10
        if context["total_tasks"] > 11:
            assert context.get("other_tasks_truncated") is True



def binary_search(arr: list[int], target: int) -> int:
    """Return the index of target in sorted arr, or -1 if not found."""
    lo, hi = 0, len(arr)  # Bug: hi should be len(arr) - 1
    while lo <= hi:
        mid = (lo + hi) // 2
        if arr[mid] == target:
            return mid
        elif arr[mid] < target:
            lo = mid + 1
        else:
            hi = mid - 1
    return -1



N = int(input())
S = input()
se = set()
se.add((0, 0))
now = (0, 0)
for i in range(N):
    if S[i] == "L":
        now = (now[0] - 1, now[1])
    if S[i] == "R":
        now = (now[0] + 1, now[1])
    if S[i] == "U":
        now = (now[0], now[1] + 1)
    if S[i] == "D":
        now = (now[0], now[1] - 1)
    se.add(now)
if len(se) == N + 1:
    print("Yes")
else:
    print("No")



N = int(input())
S = input()

from itertools import groupby

gb = [[key, len(list(g))] for key, g in groupby(S)]


def swap(s):
    res = []
    for c in s[::-1]:
        if c == "d":
            res.append("p")
        else:
            res.append("d")
    return "".join(res)


ans = [S]
for i, c in enumerate(S):
    if c == "p":
        for j in range(i + 1, N):
            ans.append(S[:i] + swap(S[i:j]) + S[j:])
        break
print(sorted(ans)[0])



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5 7\n1 2 (\n2 3 )\n3 4 (\n4 1 )\n2 4 )\n4 5 (\n5 1 )\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 2\n1 2 )\n2 1 )\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10 20\n4 5 (\n5 6 (\n6 7 )\n2 5 )\n5 8 (\n6 3 )\n8 5 )\n1 2 (\n9 10 (\n4 7 (\n3 4 )\n8 9 (\n2 1 )\n1 4 )\n2 3 )\n3 2 (\n7 8 (\n7 4 )\n10 9 )\n9 8 )\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 2\n1 2 (\n2 1 )\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 2\n1 2 (\n2 1 (\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='4\n1 10\n8 13\n3 4\n5 20\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '8 8 4 5\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3\n20 24\n3 24\n1 75\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '20 20 20\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='15\n335279264 849598327\n446755913 822889311\n526239859 548830120\n181424399 715477619\n342858071 625711486\n448565595 480845266\n467825612 647639160\n160714711 449656269\n336869678 545923679\n61020590 573085537\n626006012 816372580\n135599877 389312924\n511429216 547865075\n561330066 605997004\n539239436 921749002\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '526239859 526239859 526239859 467825612 467825612 467825612 467825612 449656269 449656269 449656269 626006012 389312924 511429216 561330066 561330066\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3\n4 4\n0 2\n2 3\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '4 2 2\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='7\n2 5\n0 5\n3 3\n4 5\n2 3\n3 4\n2 2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '3 3 3 4 3 3 2\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



n, l, r = map(int, input().split())

start_lis = [i for i in range(1, l)]
middle_lis = list(reversed([i for i in range(l, r + 1)]))
final_lis = [i for i in range(r + 1, n + 1)]

# 各リストをフラット化して1つのリストに結合
combined_lis = start_lis + middle_lis + final_lis

print(tuple(combined_lis))



from math import gcd
import sys

input = sys.stdin.readline
inf = float("inf")


def read(dtype=int):
    return list(map(dtype, input().split()))


t = int(input())


def diff(a):
    return [a[1] - a[0], a[2] - a[1], a[0] - a[2]]


n = 3
for _ in range(t):
    a = read()
    ans = inf
    for i in range(3):
        x = (i - 1) % n
        y = (i + 1) % n
        c = min(a[x], a[y])
        v = (max(a[y], a[x]) - c) // 3
        if (max(a[y], a[x]) - c) % 3 == 0 and a[i] + c >= v:
            ans = min(ans, c + v * 3)
    print(-1 if ans == inf else ans)



"""Tests for pytest plugin."""

import os
import subprocess
import sys
from types import SimpleNamespace

import llmdebug.pytest_plugin as pytest_plugin_module
from llmdebug import get_latest_snapshot
from llmdebug.config import SnapshotConfig


def test_plugin_captures_on_failure(tmp_path):
    """Test that the pytest plugin captures snapshots on test failures."""
    # Create a test file
    test_file = tmp_path / "test_example.py"
    test_file.write_text(
        """
def test_failing():
    x = [1, 2, 3]
    assert False, "intentional failure"
"""
    )

    # Run pytest in subprocess
    result = subprocess.run(
        [sys.executable, "-m", "pytest", str(test_file), "-v"],
        cwd=tmp_path,
        capture_output=True,
        text=True,
    )

    # Test should fail
    assert result.returncode != 0

    # Check that snapshot was created
    llmdebug_dir = tmp_path / ".llmdebug"
    assert llmdebug_dir.exists(), f"No .llmdebug dir. stderr: {result.stderr}"

    snapshots = list(llmdebug_dir.glob("*.json"))
    assert len(snapshots) >= 1  # At least the snapshot (and maybe latest.json)

    # Check that repro command is present (use get_latest_snapshot to auto-expand keys)
    snapshot = get_latest_snapshot(str(llmdebug_dir))
    assert snapshot is not None, "Failed to read snapshot"
    repro = snapshot.get("pytest", {}).get("repro")
    assert isinstance(repro, list)
    assert "-m" in repro
    assert "pytest" in repro
    assert "test_example.py::test_failing" in repro


def test_no_snapshot_marker(tmp_path):
    """Test that no_snapshot marker prevents capture."""
    test_file = tmp_path / "test_no_capture.py"
    test_file.write_text(
        """
import pytest

@pytest.mark.no_snapshot
def test_failing_no_capture():
    assert False, "should not capture"
"""
    )

    result = subprocess.run(
        [sys.executable, "-m", "pytest", str(test_file), "-v"],
        cwd=tmp_path,
        capture_output=True,
        text=True,
    )

    # Test should fail
    assert result.returncode != 0

    # Check that no snapshot was created for this specific test
    llmdebug_dir = tmp_path / ".llmdebug"
    if llmdebug_dir.exists():
        snapshots = list(llmdebug_dir.glob("*test_failing_no_capture*.json"))
        assert len(snapshots) == 0, "Snapshot should not be created for no_snapshot marker"


def test_passing_test_no_snapshot(tmp_path):
    """Test that passing tests don't create snapshots."""
    test_file = tmp_path / "test_passing.py"
    test_file.write_text(
        """
def test_passing():
    assert True
"""
    )

    result = subprocess.run(
        [sys.executable, "-m", "pytest", str(test_file), "-v"],
        cwd=tmp_path,
        capture_output=True,
        text=True,
    )

    # Test should pass
    assert result.returncode == 0

    # Check that no snapshot was created
    llmdebug_dir = tmp_path / ".llmdebug"
    assert not llmdebug_dir.exists() or len(list(llmdebug_dir.glob("*.json"))) == 0


def _run_pytest_and_get_snapshot(tmp_path, test_code, env_overrides=None):
    """Helper: write test file, run pytest subprocess, return snapshot."""
    test_file = tmp_path / "test_subject.py"
    test_file.write_text(test_code)

    env = os.environ.copy()
    if env_overrides:
        env.update(env_overrides)

    result = subprocess.run(
        [sys.executable, "-m", "pytest", str(test_file), "-v"],
        cwd=tmp_path,
        capture_output=True,
        text=True,
        env=env,
    )
    assert result.returncode != 0, f"Test was expected to fail.\nstdout:\n{result.stdout}"

    llmdebug_dir = tmp_path / ".llmdebug"
    assert llmdebug_dir.exists(), f"No .llmdebug dir. stderr: {result.stderr}"

    snapshot = get_latest_snapshot(str(llmdebug_dir))
    assert snapshot is not None, "Failed to read snapshot"
    return snapshot


def test_fixture_values_in_snapshot(tmp_path):
    """Test that custom fixture values appear in the snapshot and internal fixtures are excluded."""
    snapshot = _run_pytest_and_get_snapshot(
        tmp_path,
        """
import pytest

@pytest.fixture
def data():
    return [1, 2, 3]

@pytest.fixture
def label():
    return "hello"

def test_with_fixtures(data, label, request):
    assert False, "intentional failure"
""",
    )
    pytest_ctx = snapshot["pytest"]
    fixtures = pytest_ctx.get("fixtures")
    assert fixtures is not None, f"Expected 'fixtures' key. pytest keys: {list(pytest_ctx.keys())}"
    assert "data" in fixtures
    assert "label" in fixtures
    # Internal fixture 'request' should be excluded
    assert "request" not in fixtures


def test_markers_in_snapshot(tmp_path):
    """Test that custom markers and timeout marker appear in the snapshot."""
    snapshot = _run_pytest_and_get_snapshot(
        tmp_path,
        """
import pytest

@pytest.mark.slow
@pytest.mark.timeout(30)
def test_marked():
    assert False, "intentional failure"
""",
    )
    pytest_ctx = snapshot["pytest"]
    markers = pytest_ctx.get("markers")
    assert markers is not None, f"Expected 'markers' key. pytest keys: {list(pytest_ctx.keys())}"
    assert "slow" in markers
    # timeout marker is captured separately in timeout_config, but also appears in markers
    assert "timeout" in markers

    # Timeout config should also be set
    toc = pytest_ctx.get("timeout_config")
    assert toc is not None, f"Expected 'timeout_config' key. pytest keys: {list(pytest_ctx.keys())}"
    assert toc["seconds"] == 30


def test_param_indices_in_snapshot(tmp_path):
    """Test that parametrize indices are captured."""
    snapshot = _run_pytest_and_get_snapshot(
        tmp_path,
        """
import pytest

@pytest.mark.parametrize("x", [10, 20, 30])
def test_param(x):
    if x == 20:
        assert False, "fails on 20"
""",
    )
    pytest_ctx = snapshot["pytest"]
    param_indices = pytest_ctx.get("param_indices")
    assert param_indices is not None, (
        f"Expected 'param_indices'. pytest keys: {list(pytest_ctx.keys())}"
    )
    assert "x" in param_indices
    # x=20 is index 1 in the parametrize list [10, 20, 30]
    assert param_indices["x"] == 1


def test_internal_fixtures_excluded(tmp_path):
    """Test that internal/noisy fixtures like capsys and tmp_path don't appear."""
    snapshot = _run_pytest_and_get_snapshot(
        tmp_path,
        """
def test_with_capsys(capsys, tmp_path):
    print("hello")
    assert False, "intentional failure"
""",
    )
    pytest_ctx = snapshot["pytest"]
    fixtures = pytest_ctx.get("fixtures", {})
    assert "capsys" not in fixtures
    # tmp_path is NOT in the exclude list and should appear
    assert "tmp_path" in fixtures


def test_fixtures_disabled_by_env(tmp_path):
    """Test that LLMDEBUG_INCLUDE_FIXTURES=false suppresses fixtures."""
    snapshot = _run_pytest_and_get_snapshot(
        tmp_path,
        """
import pytest

@pytest.fixture
def data():
    return [1, 2, 3]

def test_with_fixture(data):
    assert False, "intentional failure"
""",
        env_overrides={"LLMDEBUG_INCLUDE_FIXTURES": "false"},
    )
    pytest_ctx = snapshot["pytest"]
    assert "fixtures" not in pytest_ctx


def test_redaction_profile_from_env(tmp_path):
    """Test that redaction profile env applies to pytest snapshot capture."""
    snapshot = _run_pytest_and_get_snapshot(
        tmp_path,
        """
def test_secret_failure():
    assert False, "password=secret123"
""",
        env_overrides={"LLMDEBUG_REDACTION_PROFILE": "prod"},
    )
    message = snapshot["exception"]["message"]
    assert "[REDACTED]" in message
    assert "password=secret123" not in message


class _DummyMarker:
    def __init__(
        self,
        name: str,
        args: tuple[object, ...] = (),
        kwargs: dict[str, object] | None = None,
    ):
        self.name = name
        self.args = args
        self.kwargs = kwargs or {}


class _DummyCallSpec:
    def __init__(self) -> None:
        self.params = {"x": 1}
        self.indices = {"x": 0}


class _DummyItem:
    def __init__(self, *, include_no_snapshot: bool = False) -> None:
        self.nodeid = "tests/test_subject.py::test_case"
        self.stash: dict[object, list[str]] = {}
        self.fixturenames = ["data", "request"]
        self.funcargs = {"data": [1, 2, 3], "request": "ignored"}
        self.callspec = _DummyCallSpec()
        self.config = SimpleNamespace(workerinput={"workerid": "gw0"})
        self._include_no_snapshot = include_no_snapshot

    def get_closest_marker(self, name: str):
        if name == "timeout":
            return _DummyMarker("timeout", args=(30,))
        if name == "no_snapshot" and self._include_no_snapshot:
            return _DummyMarker("no_snapshot")
        return None

    def iter_markers(self):
        return [
            _DummyMarker("slow"),
            _DummyMarker("timeout", args=(30,), kwargs={"method": "thread"}),
            _DummyMarker("parametrize"),
        ]


class _DummyReport:
    when = "call"
    failed = True
    outcome = "failed"
    nodeid = "tests/test_subject.py::test_case"
    longreprtext = "assert False"
    capstdout = "stdout text"
    capstderr = "stderr text"


class _DummyOutcome:
    def __init__(self, report) -> None:
        self._report = report

    def get_result(self):
        return self._report


class _DummyExcInfo:
    def __init__(self, exc: Exception) -> None:
        self.value = exc
        self.tb = exc.__traceback__


def _run_hook(item, call, report) -> None:
    hook = pytest_plugin_module.pytest_runtest_makereport(item, call)
    next(hook)
    try:
        hook.send(_DummyOutcome(report))
    except StopIteration:
        pass


def test_pytest_plugin_helpers_build_config_and_context(monkeypatch, capsys):
    monkeypatch.setenv("LLMDEBUG_INCLUDE_MODULES", "pkg.alpha, pkg.beta")
    monkeypatch.setenv("LLMDEBUG_REDACTION_PROFILE", "invalid-profile")
    monkeypatch.setenv("LLMDEBUG_OUTPUT_FORMAT", "toon")

    cfg = pytest_plugin_module._build_snapshot_config_from_env(debug=True)
    assert isinstance(cfg, SnapshotConfig)
    assert cfg.include_modules == ("pkg.alpha", "pkg.beta")
    assert cfg.output_format == "toon"

    stderr = capsys.readouterr().err
    assert "llmdebug:" in stderr
    assert pytest_plugin_module._parse_include_modules("a,b,, c ") == ("a", "b", "c")
    assert pytest_plugin_module._resolve_output_format("json") == "json"
    assert pytest_plugin_module._resolve_output_format("unknown") == "json_compact"

    item = _DummyItem()
    report = _DummyReport()
    pytest_context, callspec = pytest_plugin_module._build_base_pytest_context(item, report, cfg)
    assert pytest_context["nodeid"] == report.nodeid
    assert callspec is item.callspec

    pytest_plugin_module._capture_fixture_context(item, cfg, pytest_context)
    assert "fixtures" in pytest_context
    fixtures = pytest_context["fixtures"]
    assert isinstance(fixtures, dict)
    assert "request" not in fixtures

    pytest_plugin_module._capture_marker_context(item, cfg, pytest_context)
    assert "markers" in pytest_context
    markers = pytest_context["markers"]
    assert isinstance(markers, dict)
    assert "slow" in markers
    assert "parametrize" not in markers

    pytest_plugin_module._capture_timeout_context(item, cfg, pytest_context)
    timeout_config = pytest_context["timeout_config"]
    assert isinstance(timeout_config, dict)
    assert timeout_config["seconds"] == 30

    pytest_plugin_module._capture_param_indices(item.callspec, pytest_context)
    param_indices = pytest_context["param_indices"]
    assert isinstance(param_indices, dict)
    assert param_indices["x"] == 0

    pytest_plugin_module._capture_xdist_worker(item, pytest_context)
    assert pytest_context["xdist_worker"] == "gw0"

    item.stash[pytest_plugin_module._flaky_key] = ["failed", "passed"]
    pytest_plugin_module._capture_flaky_metadata(item, pytest_context)
    assert pytest_context["flaky"] is True

    warnings: list[str] = []
    pytest_plugin_module._capture_context_block(
        warnings,
        "boom",
        lambda: (_ for _ in ()).throw(RuntimeError("x")),
    )
    assert warnings and "boom" in warnings[0]


def test_pytest_plugin_hook_calls_capture_exception(monkeypatch):
    captured: dict[str, object] = {}

    def _fake_capture_exception(name, exc, tb, cfg, *, extra):
        captured["name"] = name
        captured["exc"] = exc
        captured["tb"] = tb
        captured["cfg"] = cfg
        captured["extra"] = extra

    monkeypatch.setattr(pytest_plugin_module, "capture_exception", _fake_capture_exception)
    monkeypatch.setattr(
        pytest_plugin_module,
        "_build_snapshot_config_from_env",
        lambda _debug: SnapshotConfig(output_format="json"),
    )
    monkeypatch.setattr(
        pytest_plugin_module,
        "_capture_coverage_context",
        lambda *_args, **_kwargs: {"files": []},
    )

    item = _DummyItem()
    report = _DummyReport()
    try:
        raise RuntimeError("hook failure")
    except RuntimeError as exc:
        call = SimpleNamespace(excinfo=_DummyExcInfo(exc))

    _run_hook(item, call, report)

    assert captured["name"] == "tests_test_subject.py_test_case"
    extra = captured["extra"]
    assert isinstance(extra, dict)
    assert "pytest" in extra
    pytest_context = extra["pytest"]
    assert pytest_context["nodeid"] == report.nodeid
    assert "coverage" in pytest_context
    assert pytest_context["xdist_worker"] == "gw0"
    assert item.stash[pytest_plugin_module._flaky_key] == ["failed"]


def test_pytest_plugin_hook_handles_no_snapshot_and_missing_excinfo(monkeypatch):
    called = {"count": 0}
    monkeypatch.setattr(
        pytest_plugin_module,
        "capture_exception",
        lambda *_args, **_kwargs: called.__setitem__("count", called["count"] + 1),
    )
    monkeypatch.setattr(
        pytest_plugin_module,
        "_build_snapshot_config_from_env",
        lambda _debug: SnapshotConfig(output_format="json"),
    )

    report = _DummyReport()
    no_snap_item = _DummyItem(include_no_snapshot=True)
    _run_hook(no_snap_item, SimpleNamespace(excinfo=None), report)

    regular_item = _DummyItem()
    _run_hook(regular_item, SimpleNamespace(excinfo=None), report)
    assert called["count"] == 0


def test_pytest_plugin_hook_logs_capture_exception_failures(monkeypatch, capsys):
    monkeypatch.setattr(
        pytest_plugin_module,
        "capture_exception",
        lambda *_args, **_kwargs: (_ for _ in ()).throw(RuntimeError("capture boom")),
    )
    monkeypatch.setattr(
        pytest_plugin_module,
        "_build_snapshot_config_from_env",
        lambda _debug: SnapshotConfig(debug=True, output_format="json"),
    )

    item = _DummyItem()
    report = _DummyReport()
    try:
        raise ValueError("hook failure")
    except ValueError as exc:
        call = SimpleNamespace(excinfo=_DummyExcInfo(exc))

    _run_hook(item, call, report)
    stderr = capsys.readouterr().err
    assert "capture failed for tests_test_subject.py_test_case" in stderr



from bisect import *

B = bisect_left
N, *A = map(int, open(0).read().split())
o = [1] * N
F = 1 << 60
A = A + [-F]
for k in [-1, 1]:
    d = [F] * N
    for i in range(N):
        o[i] += B(d, A[i + k] - k)
        d[B(d, A[i])] = A[i]
    o = o[::-1]
    A = [-e for e in A][~0:0:-1]
    A += (F,)
print(max(o))



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def findTheArrayConcVal(self, nums: List[int]) -> int:
        left = 0
        right = len(nums) - 1
        total = 0
        while left <= right:
            if left > right:
                total += int(str(nums[left]) + str(nums[right]))
            else:
                total += nums[left]
            left += 1
            right -= 1
        return total



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3 2\n3 2 5\n4 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3 2\n3 1 5\n4 2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1 1\n1\n2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10 22\n131 111 16 149 41 15 44 164 46 135\n81 58 159 99 127 12 49 125 55 65 121 177 37 75 11 24 113 176 26 88 122 95\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10 13\n28 82 62 38 200 167 191 68 130 90\n87 47 154 193 6 64 61 184 77 93 163 34 126\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.minOperationsMaxProfit([8,3], 5, 6)
    assert result == 3


def test_case_1():
    sol = Solution()
    result = sol.minOperationsMaxProfit([10,9,6], 6, 4)
    assert result == 7


def test_case_2():
    sol = Solution()
    result = sol.minOperationsMaxProfit([3,4,0,5,1], 1, 92)
    assert result == -1



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def getMaximumConsecutive(self, coins: List[int]) -> int:
        ans = 1  # next value we want to make

        for coin in sorted(coins):
            if coin > ans:
                return ans
            ans += coin

    return ans



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='6 3\n101010\n-5 -1 0 1 2 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '5\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='13 656320850\n0100110011101\n-900549713 -713494784 -713078652 -687818593 -517374932 -498415009 -472742091 -390030458 -379340552 -237481538 -44636942 352721061 695864366\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '14\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



from collections import defaultdict

H, W, E = map(int, input().split())
A = list(map(int, input().split()))

D = defaultdict(int)
for a in A:
    D[a] += 1
D = sorted(D.items(), reverse=True, key=lambda x: x[0])
# print(D)

flag = True
area = 0
for a, n in D:
    N = (H // (2**a)) * (W // (2**a))
    area += (2**a) ** 2 * n
    # print(a,n,N,area)
    if area >= (2**a) ** 2 * N:
        flag = False
if flag:
    print("Yes")
else:
    print("No")



from bisect import *

N, L = map(int, input().split())
inf = L * 4
A = list(map(int, input().split()))
ans = inf
for a in A:
    b = L - a
    p = bisect_left(A, b)
    p1 = A[p] if p < N else inf
    p2 = A[p - 1]
    ans_ = 2 * L + min(abs(b - p1), abs(b - p2))
    ans = min(ans, ans_)
print(ans)



n = int(input())
a = list(map(int, input().split()))
s = [list(map(str, input())) for i in range(n)]
q = int(input())
ans = [[[10**9, 10**20] for i in range(n)] for i in range(n)]
for i in range(n):
    ans[i][i] = [0, a[i]]
for i in range(n):
    for j in range(n):
        if s[i][j] == "Y":
            ans[i][j] = [1, a[i] + a[j]]
for k in range(n):
    for i in range(n):
        for j in range(n):
            if ans[i][j][0] > ans[i][k][0] + ans[k][j][0]:
                ans[i][j] = [ans[i][k][0] + ans[k][j][0], ans[i][k][1] + ans[k][j][1] - a[k]]
            elif ans[i][j][0] == ans[i][k][0] + ans[k][j][0]:
                ans[i][j][1] = min(ans[i][k][1] + ans[k][j][1] - a[k], ans[i][j][1])
for i in range(q):
    c, b = map(int, input().split())
    c -= 1
    b -= 1
    if ans[c][b][1] == 10**20:
        print("Impossible")
    else:
        print(*ans[c][b])



import asyncio
from collections.abc import AsyncIterator

cleanup_done: list[bool] = []


async def resource_stream(n: int) -> AsyncIterator[int]:
    cleanup_done.clear()
    try:
        for i in range(n):
            await asyncio.sleep(0)
            yield i * 10
    finally:
        await asyncio.sleep(0)
        cleanup_done.append(True)


def get_first(n: int, limit: int) -> tuple[list[int], bool]:
    loop = asyncio.new_event_loop()
    gen = resource_stream(n)
    results: list[int] = []
    try:
        for _ in range(limit):
            item = loop.run_until_complete(gen.__anext__())
            results.append(item)
    except StopAsyncIteration:
        pass
    loop.close()
    cleaned = len(cleanup_done) > 0
    return results, cleaned



MOD = 998244353
N, X = map(int, input().split())
dp = [[[0] * (1 << 2 * X - 1) for _ in range(N + 1)] for _ in range(N + 1)]
dp[0][0][0] = 1
P = [1]
for i in range(N):
    P.append(P[i] * (i + 1) % MOD)

for i in range(1, N + 1):
    for j in range(i):
        for bit in range(1 << 2 * X - 1):
            # i項目を決める
            for k in range(2 * X - 1):
                if 1 <= i - X + 1 + k <= N and not bit >> k & 1:
                    dp[i][j + 1][(bit | 1 << k) >> 1] += dp[i - 1][j][bit]

            # i項目を決めない
            dp[i][j][bit >> 1] += dp[i - 1][j][bit]

print(sum(sum(dp[N][j]) * P[N - j] * pow(-1, j % 2) for j in range(N + 1)))



# 長さnのリストRと長さnのリストCが与えられます。
# また、q個のクエリが与えられます。
# 各クエリは、2つの整数aとbが与えられ、Rのa番目の要素とCのb番目の要素を足した値がnより大きい場合は'#'を、そうでない場合は'.'を出力してください。
# という問題と同義。


def solve(n, R, C, Q, queries):
    ans = []
    for r, c in queries:
        if R[r - 1] + C[c - 1] > n:
            ans.append("#")
        else:
            ans.append(".")
    return ans


if __name__ == "__main__":
    n = int(input())
    R = list(map(int, input().split()))
    C = list(map(int, input().split()))
    Q = int(input())
    queries = [list(map(int, input().split())) for _ in range(Q)]
    ans = solve(n, R, C, Q, queries)
    print(*ans)



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def largestInteger(self, num: int) -> int:
        evenlist = []
        oddlist = []
        nums = [int(x) for x in str(num)]
        for i in nums:
            if i % 2 == 0:
                evenlist.append(i)
            else:
                oddlist.append(i)
        even = [-x for x in evenlist]
        odd = [-x for x in oddlist]
        result = []
        for ele in nums:
            if ele in evenlist:
                result += [-heapq.heappop(even)]
            if ele in oddlist:
                result += [-heapq.heappop(odd)]
        result = [str(x) for x in result]
        return int("".join(result))


s = Solution()
print(s.largestInteger(1234))



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.findTheArrayConcVal([7,52,2,4])
    assert result == 596


def test_case_1():
    sol = Solution()
    result = sol.findTheArrayConcVal([5,14,13,8,12])
    assert result == 673



def merge_sorted(left: list[int], right: list[int]) -> list[int]:
    """Merge two sorted lists into one sorted list."""
    result: list[int] = []
    i, j = 0, 0
    while i < len(left) and j < len(right):
        if left[i] >= right[j]:  # Bug: should be <= for stable ascending merge
            result.append(left[i])
            i += 1
        else:
            result.append(right[j])
            j += 1
    result.extend(left[i:])
    result.extend(right[j:])
    return result


def merge_sort(arr: list[int]) -> list[int]:
    """Sort a list using merge sort."""
    if len(arr) <= 1:
        return arr[:]
    mid = len(arr) // 2
    left = merge_sort(arr[:mid])
    right = merge_sort(arr[mid:])
    return merge_sorted(left, right)



from heapq import heappush, heappop, heapify
from collections import defaultdict, deque, Counter
from math import ceil, floor, sqrt, factorial, gcd, cos, sin, pi
from itertools import permutations, combinations, product
from bisect import bisect_left, bisect_right
from copy import deepcopy
from fractions import Fraction
from random import randint
import sys
from functools import cache, lru_cache  # @lru_cache(maxsize=None)
from time import time

# from sortedcontainers import SortedList # type: ignore
# sys.setrecursionlimit(10**6)
vector1 = [[0, -1], [1, 0], [0, 1], [-1, 0]]
vector2 = [[0, 1], [1, 0], [-1, 0], [0, -1], [1, -1], [-1, 1], [1, 1], [-1, -1]]
alphabet = "abcdefghijklmnopqrstuvwxyz"


def main():
    N, M, L = map(int, input().split())
    a = list(map(int, input().split()))
    b = list(map(int, input().split()))
    a = [(val, i + 1) for i, val in enumerate(a)]
    b = [(val, i + 1) for i, val in enumerate(b)]
    a.sort(reverse=True)
    b.sort(reverse=True)
    print(a)
    print(b)
    s = set()
    for _ in range(L):
        c, d = map(int, input().split())
        s.add((c, d))
    ans = 0
    for i in range(N):
        for j in range(M):
            av, ai = a[i]
            bv, bi = b[j]
            if (ai, bi) in s:
                continue
            else:
                ans = max(ans, av + bv)
                if j == 0:
                    print(ans)
                    exit()
                break
    print(ans)


if __name__ == "__main__":
    main()



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools
class Solution:
def wordSubsets(self, words1: List[str], words2: List[str]) -> List[str]:
    w2 = reduce(operator.or_, map(Counter, words2))
    return [w1 for w1 in words1 if Counter(w1) >= w2]



import sys

sys.setrecursionlimit((1 << 19) - 1)


def dfs(pos):
    global ans
    cnt = 0
    less = set()
    for i in tree[pos]:
        tocnt, toless = dfs(i)
        cnt += tocnt
        less = less | toless
    if A[pos] == -1:
        cnt += 1
    elif A[pos] <= K:
        less.add(pos)
    if K not in less and len(less) >= K - cnt and cnt <= 1:
        ans = "Alice"
    return cnt, less


T = int(input())
for _ in range(T):
    N, K = map(int, input().split())
    P = list(map(int, input().split()))
    A = list(map(int, input().split()))
    ans = "Bob"
    tree = [set() for i in range(N)]
    for i in range(N - 1):
        tree[P[i] - 1].add(i + 1)
    dfs(0)
    print(ans)



n = int(input())
s = input()

right, now, ans = 0, 0, 0
for left in range(n):
    while right < n and s[right] == "o":
        now += 1
        right += 1
    ans = max(ans, right - left)
    if right == left:
        right += 1
    else:
        now -= 1 if s[left] == "o" else 0
print(ans if ans != 0 else -1)



n, m = list(map(int, input().split()))
l = [int(x) for x in input().split()]
d = dict()
for i in l:
    if i in d:
        d[i] += 1
    else:
        d[i] = 1
yes = True
nl = [int(x) for x in input().split()]
for i in nl:
    if i not in d or d[i] == 0:
        yes = False
        break

print("Yes" if yes else "No")



"""Tests for production exception hooks."""

from __future__ import annotations

import re
import sys
import threading
import time
from pathlib import Path
from types import SimpleNamespace
from typing import Any, cast

import pytest

from llmdebug.hooks import (
    PII_PATTERNS,
    HookName,
    _build_production_config,
    _capture_safely,
    _RateLimiter,
    install_hooks,
    uninstall_hooks,
)

from .conftest import read_latest_snapshot

# ---------------------------------------------------------------------------
# Fixtures
# ---------------------------------------------------------------------------


@pytest.fixture(autouse=True)
def _cleanup_hooks():
    """Ensure hooks are uninstalled after each test."""
    yield
    uninstall_hooks()


def _make_exc_with_tb() -> tuple[BaseException, Any]:
    """Create a real exception with traceback for testing."""
    try:
        raise ValueError("test crash")
    except ValueError as e:
        return e, e.__traceback__


# ---------------------------------------------------------------------------
# _RateLimiter
# ---------------------------------------------------------------------------


class TestRateLimiter:
    def test_rejects_zero_max_captures(self):
        with pytest.raises(ValueError, match="max_captures must be >= 1"):
            _RateLimiter(max_captures=0, window_seconds=60.0)

    def test_rejects_negative_max_captures(self):
        with pytest.raises(ValueError, match="max_captures must be >= 1"):
            _RateLimiter(max_captures=-1, window_seconds=60.0)

    def test_rejects_zero_window(self):
        with pytest.raises(ValueError, match="window_seconds must be > 0"):
            _RateLimiter(max_captures=10, window_seconds=0)

    def test_rejects_negative_window(self):
        with pytest.raises(ValueError, match="window_seconds must be > 0"):
            _RateLimiter(max_captures=10, window_seconds=-1.0)

    def test_allows_under_limit(self):
        limiter = _RateLimiter(max_captures=3, window_seconds=60.0)
        assert limiter.allow("ValueError", "test.py", 10) is True
        assert limiter.allow("ValueError", "test.py", 10) is True
        assert limiter.allow("ValueError", "test.py", 10) is True

    def test_blocks_over_limit(self):
        limiter = _RateLimiter(max_captures=2, window_seconds=60.0)
        assert limiter.allow("ValueError", "test.py", 10) is True
        assert limiter.allow("ValueError", "test.py", 10) is True
        assert limiter.allow("ValueError", "test.py", 10) is False

    def test_window_expiry(self):
        limiter = _RateLimiter(max_captures=1, window_seconds=0.1)
        assert limiter.allow("ValueError", "test.py", 10) is True
        assert limiter.allow("ValueError", "test.py", 10) is False
        # Wait for window to expire
        time.sleep(0.15)
        assert limiter.allow("ValueError", "test.py", 10) is True

    def test_different_signatures_independent(self):
        limiter = _RateLimiter(max_captures=1, window_seconds=60.0)
        assert limiter.allow("ValueError", "test.py", 10) is True
        assert limiter.allow("ValueError", "test.py", 10) is False
        # Different exception type
        assert limiter.allow("TypeError", "test.py", 10) is True
        # Different file
        assert limiter.allow("ValueError", "other.py", 10) is True
        # Different line
        assert limiter.allow("ValueError", "test.py", 20) is True

    def test_thread_safety(self):
        limiter = _RateLimiter(max_captures=100, window_seconds=60.0)
        results: list[bool] = []
        lock = threading.Lock()

        def hammer():
            for _ in range(50):
                result = limiter.allow("ValueError", "test.py", 10)
                with lock:
                    results.append(result)

        threads = [threading.Thread(target=hammer) for _ in range(10)]
        for t in threads:
            t.start()
        for t in threads:
            t.join()

        # Exactly 100 should be True, rest False
        assert sum(results) == 100
        assert len(results) == 500


# ---------------------------------------------------------------------------
# _capture_safely
# ---------------------------------------------------------------------------


class TestCaptureSafely:
    def test_captures_exception(self, tmp_path: Path):
        cfg = _build_production_config(str(tmp_path), pii_safe=False)
        limiter = _RateLimiter(10, 60.0)
        exc, tb = _make_exc_with_tb()

        _capture_safely("test", exc, tb, cfg, limiter)

        snapshot = read_latest_snapshot(tmp_path)
        assert snapshot["exception"]["type"] == "ValueError"
        assert snapshot["exception"]["message"] == "test crash"
        assert snapshot["name"] == "test"

    def test_swallows_capture_errors(self):
        """A broken config should not cause _capture_safely to raise."""
        # Use an invalid out_dir that will fail on write
        cfg = _build_production_config("/nonexistent/deeply/nested/path", pii_safe=False)
        limiter = _RateLimiter(10, 60.0)
        exc, tb = _make_exc_with_tb()

        # Should not raise
        _capture_safely("test", exc, tb, cfg, limiter)

    def test_rate_limited(self, tmp_path: Path):
        cfg = _build_production_config(str(tmp_path), pii_safe=False)
        limiter = _RateLimiter(1, 60.0)
        exc, tb = _make_exc_with_tb()

        _capture_safely("test", exc, tb, cfg, limiter)
        # Second call with same signature should be rate-limited
        _capture_safely("test_2", exc, tb, cfg, limiter)

        # Only one snapshot should exist; latest still has the first name
        snapshot = read_latest_snapshot(tmp_path)
        assert snapshot["name"] == "test"

    def test_handles_none_traceback(self, tmp_path: Path):
        """When tb is None, capture_safely should handle gracefully."""
        cfg = _build_production_config(str(tmp_path), pii_safe=False)
        limiter = _RateLimiter(10, 60.0)
        exc = ValueError("no traceback")

        # Should not raise — tb.extract_tb(None) returns empty list
        _capture_safely("test", exc, None, cfg, limiter)

    def test_includes_extra(self, tmp_path: Path):
        cfg = _build_production_config(str(tmp_path), pii_safe=False)
        limiter = _RateLimiter(10, 60.0)
        exc, tb = _make_exc_with_tb()

        _capture_safely("test", exc, tb, cfg, limiter, extra={"hook": "sys.excepthook"})

        snapshot = read_latest_snapshot(tmp_path)
        assert snapshot["hook"] == "sys.excepthook"


# ---------------------------------------------------------------------------
# install_hooks / uninstall_hooks
# ---------------------------------------------------------------------------


class TestInstallHooks:
    def test_installs_and_uninstalls(self):
        original_excepthook = sys.excepthook
        original_threading = threading.excepthook
        original_unraisable = sys.unraisablehook

        install_hooks()

        assert sys.excepthook is not original_excepthook
        assert threading.excepthook is not original_threading
        assert sys.unraisablehook is not original_unraisable

        uninstall_hooks()

        assert sys.excepthook is original_excepthook
        assert threading.excepthook is original_threading
        assert sys.unraisablehook is original_unraisable

    def test_idempotent_install(self):
        install_hooks()
        hook_after_first = sys.excepthook

        install_hooks()  # Second call should be a no-op
        assert sys.excepthook is hook_after_first

    def test_idempotent_uninstall(self):
        """Uninstalling when not installed should be a no-op."""
        uninstall_hooks()  # Should not raise

    def test_preserves_original_excepthook(self):
        """Our hook should call the original after capturing."""
        calls: list[tuple[Any, ...]] = []
        original = sys.excepthook

        def tracking_hook(exc_type, exc_value, exc_tb):
            calls.append((exc_type, exc_value, exc_tb))

        sys.excepthook = tracking_hook
        try:
            install_hooks()
            exc, tb = _make_exc_with_tb()
            sys.excepthook(type(exc), exc, tb)

            # Original (tracking) hook should have been called
            assert len(calls) == 1
            assert calls[0][0] is ValueError
        finally:
            sys.excepthook = original

    def test_excepthook_captures_snapshot(self, tmp_path: Path):
        # Use a no-op original to suppress traceback printing
        original = sys.excepthook
        sys.excepthook = lambda *a: None
        try:
            install_hooks(out_dir=str(tmp_path), pii_safe=False)
            exc, tb = _make_exc_with_tb()
            sys.excepthook(type(exc), exc, tb)
        finally:
            # uninstall_hooks will restore the no-op; reset to real original
            uninstall_hooks()
            sys.excepthook = original

        snapshot = read_latest_snapshot(tmp_path)
        assert snapshot["name"] == "unhandled"
        assert snapshot["hook"] == "sys.excepthook"
        assert snapshot["exception"]["type"] == "ValueError"

    def test_threading_hook_captures_snapshot(self, tmp_path: Path):
        # Replace threading.excepthook with a no-op before install so our
        # wrapper's "call original" doesn't trigger pytest's thread exception
        # handler.
        original = threading.excepthook
        threading.excepthook = lambda args: None
        try:
            install_hooks(out_dir=str(tmp_path), pii_safe=False, hooks=("threading",))
            exc, tb = _make_exc_with_tb()

            args = SimpleNamespace(
                exc_type=type(exc),
                exc_value=exc,
                exc_traceback=tb,
                thread=SimpleNamespace(name="worker-1"),
            )
            args = cast(Any, args)
            threading.excepthook(args)
        finally:
            uninstall_hooks()
            threading.excepthook = original

        snapshot = read_latest_snapshot(tmp_path)
        assert snapshot["name"] == "thread_crash"
        assert snapshot["hook"] == "threading.excepthook"
        assert snapshot["thread"] == "worker-1"

    def test_unraisable_hook_captures_snapshot(self, tmp_path: Path):
        # Replace sys.unraisablehook with a no-op before install so our
        # wrapper's "call original" doesn't trigger pytest's handler.
        original = sys.unraisablehook
        sys.unraisablehook = lambda u: None
        try:
            install_hooks(out_dir=str(tmp_path), pii_safe=False, hooks=("unraisable",))
            exc, tb = _make_exc_with_tb()

            unraisable = SimpleNamespace(
                exc_type=type(exc),
                exc_value=exc,
                exc_traceback=tb,
                err_msg=None,
                object=None,
            )
            unraisable = cast(Any, unraisable)
            sys.unraisablehook(unraisable)
        finally:
            uninstall_hooks()
            sys.unraisablehook = original

        snapshot = read_latest_snapshot(tmp_path)
        assert snapshot["name"] == "unraisable"
        assert snapshot["hook"] == "sys.unraisablehook"

    def test_asyncio_handler_captures_snapshot(self, tmp_path: Path):
        import asyncio

        async def run():
            install_hooks(
                out_dir=str(tmp_path),
                pii_safe=False,
                hooks=("asyncio",),
            )

            loop = asyncio.get_running_loop()
            exc, tb = _make_exc_with_tb()
            exc.__traceback__ = tb
            loop.call_exception_handler({"message": "test failure", "exception": exc})

        asyncio.run(run())

        snapshot = read_latest_snapshot(tmp_path)
        assert snapshot["name"] == "asyncio"
        assert snapshot["hook"] == "asyncio"
        assert snapshot["message"] == "test failure"

    def test_pii_safe_applies_patterns(self):
        cfg = _build_production_config(".llmdebug", pii_safe=True)
        assert len(cfg.redact) == len(PII_PATTERNS)
        for pattern in cfg.redact:
            assert isinstance(pattern, str)

    def test_pii_safe_disabled(self):
        cfg = _build_production_config(".llmdebug", pii_safe=False)
        assert cfg.redact == ()

    def test_redaction_profile_override_applies(self):
        cfg = _build_production_config(
            ".llmdebug",
            pii_safe=False,
            redaction_profile="prod",
        )
        assert cfg.redaction_profile == "prod"
        assert cfg.redact_traceback is True
        assert cfg.redact_exception_strings is True
        assert len(cfg.redact) > 0

    def test_pii_safe_default_preserves_traceback_behavior(self):
        cfg = _build_production_config(".llmdebug", pii_safe=True)
        assert cfg.redact_traceback is False
        assert cfg.redact_exception_strings is False

    def test_config_overrides(self):
        cfg = _build_production_config(".llmdebug", pii_safe=False, max_str=200, max_items=10)
        assert cfg.max_str == 200
        assert cfg.max_items == 10
        # Production defaults should still apply
        assert cfg.source_mode == "crash_only"
        assert cfg.frames == 10

    def test_selective_hooks(self):
        """Installing only 'excepthook' should leave others untouched."""
        original_threading = threading.excepthook
        original_unraisable = sys.unraisablehook

        install_hooks(hooks=("excepthook",))

        assert sys.excepthook is not sys.__excepthook__
        assert threading.excepthook is original_threading
        assert sys.unraisablehook is original_unraisable

    def test_invalid_hook_name_raises(self):
        """Passing an invalid hook name should raise ValueError."""
        with pytest.raises(ValueError, match="Invalid hook name"):
            install_hooks(hooks=cast(tuple[HookName, ...], ("excepthook", "bogus")))

    def test_pii_safe_with_redact_override_raises(self):
        """Cannot override redact when pii_safe=True."""
        with pytest.raises(ValueError, match="Cannot override 'redact'"):
            install_hooks(pii_safe=True, redact=(r"custom",))

    def test_invalid_redaction_pattern_raises(self):
        """Bad regex in redact should raise ValueError at install time."""
        with pytest.raises(ValueError, match="Invalid redaction pattern"):
            install_hooks(pii_safe=False, redact=(r"[unclosed",))

    def test_threading_hook_with_no_thread(self, tmp_path: Path):
        """Thread=None in excepthook args should use '?' as thread name."""
        original = threading.excepthook
        threading.excepthook = lambda args: None
        try:
            install_hooks(out_dir=str(tmp_path), pii_safe=False, hooks=("threading",))
            exc, tb = _make_exc_with_tb()

            args = SimpleNamespace(
                exc_type=type(exc),
                exc_value=exc,
                exc_traceback=tb,
                thread=None,  # No thread info
            )
            args = cast(Any, args)
            threading.excepthook(args)
        finally:
            uninstall_hooks()
            threading.excepthook = original

        snapshot = read_latest_snapshot(tmp_path)
        assert snapshot["name"] == "thread_crash"
        assert snapshot["thread"] == "?"

    def test_keyboard_interrupt_not_captured(self, tmp_path: Path):
        """KeyboardInterrupt should pass through without capture."""
        # Install with a no-op original so our hook doesn't print
        original = sys.excepthook
        sys.excepthook = lambda *a: None
        try:
            install_hooks(out_dir=str(tmp_path), pii_safe=False, hooks=("excepthook",))

            try:
                raise KeyboardInterrupt()
            except KeyboardInterrupt as exc:
                tb = exc.__traceback__
                sys.excepthook(KeyboardInterrupt, exc, tb)
        finally:
            uninstall_hooks()
            sys.excepthook = original

        # No snapshot should be written for KeyboardInterrupt
        latest = tmp_path / "latest.json"
        assert not latest.exists()


# ---------------------------------------------------------------------------
# PII patterns
# ---------------------------------------------------------------------------


class TestPIIPatterns:
    def _matches(self, text: str) -> bool:
        return any(re.search(p, text) for p in PII_PATTERNS)

    def test_matches_password(self):
        assert self._matches("password=secret123")
        assert self._matches("PASSWORD: hunter2")

    def test_matches_api_key(self):
        assert self._matches("api_key=abcdef123456")
        assert self._matches("secret-key=xyz")
        assert self._matches("auth_token=tok123")

    def test_matches_bearer_token(self):
        assert self._matches("Bearer eyJhbGciOiJIUzI1NiJ9")

    def test_matches_email(self):
        assert self._matches("user@example.com")
        assert self._matches("contact user.name@domain.org for help")

    def test_matches_long_api_keys(self):
        assert self._matches("sk-abcdefghijklmnopqrstuvwxyz")
        assert self._matches("pk_live_abcdefghijklmnopqrst")
        assert self._matches("token-ABCDEFGHIJKLMNOPQRSTUVWXYZ")

    def test_email_regex_no_pipe_false_positive(self):
        """Pipe '|' should not match in email domains (old bug: [A-Z|a-z])."""
        assert not self._matches("foo|bar")
        assert not self._matches("some|value|here")

    def test_no_false_positives(self):
        assert not self._matches("hello world")
        assert not self._matches("x = 42")
        assert not self._matches("ValueError: invalid input")
        assert not self._matches("import os")



n = int(input())
s = input()
result = set()
ch = s[0]
length = 1
result.add((ch, length))
for i in range(1, n):
    if s[i - 1] == s[i]:
        length += 1
        result.add((ch, length))
    else:
        ch = s[i]
        length = 1
        result.add((ch, length))
result = len(result)



N = int(input())
XY = []
for i in range(N):
    XY.append(list(map(int, input().split())))
# print(N)
# print(XY)

count = 0
for i in range(N):
    for j in range(i + 1, N):
        for k in range(j + 1, N):
            # print(i,j,k)
            if (XY[k][1] - XY[i][1]) * (XY[j][0] - XY[i][0]) != (XY[j][0] - XY[i][0]) * (
                XY[k][0] - XY[i][0]
            ):
                count += 1
print(count)



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def reachableNodes(self, n: int, edges: List[List[int]], restricted: List[int]) -> int:
        adj_list = defaultdict(list)
        for x, y in edges:
            adj_list[x].append(y)
            adj_list[y].append(x)

        que = deque()
        que.append(0)
        result = 0
        visited = set()
        for node in restricted:
            visited.add(node)

        while que:
            cur = que.popleft()
            if cur in visited:
                continue
            visited.add(cur)
            result += 1
            for node in adj_list[nodes]:
                que.append(node)

        return result



from collections import defaultdict, deque

N = int(input())
XY = []
P = []

for i in range(N):
    x, y, p = list(map(int, input().split()))
    XY.append((x, y))
    P.append(p)

ok = 10**9
ng = 0
while abs(ok - ng) > 1:
    m = (ok + ng) // 2
    path = defaultdict(list)
    for i in range(N):
        p = P[i]
        for j in range(N):
            if i == j:
                continue
            if p * m >= abs(XY[i][0] - XY[j][0]) + abs(XY[i][1] - XY[j][1]):
                path[i].append(j)
    c = 0
    for i in range(N):
        Q = deque()
        check = set()
        check.add(i)
        Q.append(i)
        while len(Q) > 0:
            a = Q.popleft()
            for j in path[a]:
                if j not in check:
                    Q.append(j)
                    check.add(j)
        if len(check) == N:
            c = 1
            break
    if c:
        ok = m
    else:
        ng = m
print(ok)



class Input_kyopro:
    def II(self):
        return int(input())

    def MI(self):
        return map(int, input().split())

    def MS(self):
        return map(str, input().split())

    def LMI(self):
        return list(self.MI())

    def LMS(self):
        return list(self.MS())

    def LLI(self, N):
        return [self.LMI() for _ in range(N)]

    def LLS(self, N):
        return [self.LMS() for _ in range(N)]

    def LS(self, N):
        return [input() for _ in range(N)]

    def LSL(self, N):
        return [list(input()) for _ in range(N)]

    def LI(self, N):
        return [self.II() for _ in range(N)]


I = Input_kyopro()
# 入力
from collections import defaultdict
import sys

sys.setrecursionlimit(10**8)
N, M = I.MI()
p = I.LMI()
xy = I.LLI(M)
dic = defaultdict(lambda: -1)
for x, y in xy:
    dic[x - 1] = max(dic[x - 1], y)
G = [[] for _ in range(N)]
for i in range(N - 1):
    G[p[i] - 1].append(i + 1)
count = 0


def dfs(i, hp):
    global count
    if hp < dic[i]:
        hp = dic[i]
    if hp >= 0:
        count += 1
    for nex in G[i]:
        dfs(nex, hp - 1)


dfs(0, 0)
print(count)



#!/usr/bin/env python
import os
import sys
from io import BytesIO, IOBase


def main():
    n = int(input())
    a = list(map(int, input().split()))
    hull = [(0, a[0]), (1, a[1])]
    for i in range(2, n):
        nextv = (i, a[i])
        while True:
            v1 = hull[-1]
            v2 = hull[-2]
            grad1 = (v1[1] - v2[1]) // (v1[0] - v2[0])
            grad2 = (nextv[1] - v1[1]) // (nextv[0] - v1[0])
            if grad2 <= grad1:
                hull.pop()
                if len(hull) < 2:
                    break
            else:
                break
        hull.append(nextv)
    ans = 0
    for i in range(len(hull) - 1):
        distance = hull[i + 1][0] - hull[i][0]
        height_difference = abs(hull[i + 1][1] - hull[i][1])
        grad_min = height_difference // distance
        grad_min_dur = height_difference % distance
        p = min(hull[i][1], hull[i + 1][1])
        for j in range(distance + 1):
            ans += p
            if j >= grad_min_dur:
                p += grad_min
            else:
                p += grad_min + 1
        ans -= hull[i + 1][1]
    ans += hull[-1][1]
    print(ans)


# region fastio

BUFSIZE = 8192


class FastIO(IOBase):
    newlines = 0

    def __init__(self, file):
        self._fd = file.fileno()
        self.buffer = BytesIO()
        self.writable = "x" in file.mode or "r" not in file.mode
        self.write = self.buffer.write if self.writable else None

    def read(self):
        while True:
            b = os.read(self._fd, max(os.fstat(self._fd).st_size, BUFSIZE))
            if not b:
                break
            ptr = self.buffer.tell()
            self.buffer.seek(0, 2), self.buffer.write(b), self.buffer.seek(ptr)
        self.newlines = 0
        return self.buffer.read()

    def readline(self):
        while self.newlines == 0:
            b = os.read(self._fd, max(os.fstat(self._fd).st_size, BUFSIZE))
            self.newlines = b.count(b"\n") + (not b)
            ptr = self.buffer.tell()
            self.buffer.seek(0, 2), self.buffer.write(b), self.buffer.seek(ptr)
        self.newlines -= 1
        return self.buffer.readline()

    def flush(self):
        if self.writable:
            os.write(self._fd, self.buffer.getvalue())
            self.buffer.truncate(0), self.buffer.seek(0)


class IOWrapper(IOBase):
    def __init__(self, file):
        self.buffer = FastIO(file)
        self.flush = self.buffer.flush
        self.writable = self.buffer.writable
        self.write = lambda s: self.buffer.write(s.encode("ascii"))
        self.read = lambda: self.buffer.read().decode("ascii")
        self.readline = lambda: self.buffer.readline().decode("ascii")


sys.stdin, sys.stdout = IOWrapper(sys.stdin), IOWrapper(sys.stdout)
input = lambda: sys.stdin.readline().rstrip("\r\n")

# endregion

if __name__ == "__main__":
    main()



# a = int(input())
# b = input()
a, b = map(int, input().split())
# l = list(map(int, input().split()))
# l = [input() for _ in range(a)]
# l = [list(map(int, input().split())) for _ in range(a)]

if b % 2 <= 1:
    print("Yes")
else:
    print("No")



n = int(input())
a = [0] + list(map(int, input().split()))
e = [0] * (n + 2)
rui = [0] * (n + 2)
mod = 998244353
# e[n]=0
for i in reversed(range(1, n)):
    A = a[i]
    e[i] = rui[i + 1] - rui[i + A + 1] + (A + 1) * pow(A, mod - 2, mod)
    e[i] %= mod
    rui[i] = e[i] + rui[i + 1]
    rui[i] %= mod
print(e[1])



N, M = map(int, input().split())
raw_path = [list(map(lambda i: int(i) - 1, input().split())) for _ in range(M)]


class UnionFind:
    def __init__(self, n):
        self.n = n
        self.parents = [-1] * n

    def find(self, x):
        if self.parents[x] < 0:
            return x
        else:
            self.parents[x] = self.find(self.parents[x])  # 経路圧縮
        return self.parents[x]

    def union(self, x, y):
        x = self.find(x)
        y = self.find(y)

        if x == y:
            return

        if self.parents[x] > self.parents[y]:  # ランクによる軽量化
            x, y = y, x

        self.parents[x] += self.parents[y]  # 負の数が大きくなるほど、ノードの数が多いということ
        self.parents[y] = x


unionFind = UnionFind(N)
result_flag = True

counter = [0] * N

for p in raw_path:
    counter[p[0]] += 1
    counter[p[1]] += 1
    if unionFind.find(p[0]) == unionFind.find(p[1]):
        result_flag = False
        break
    unionFind.union(p[0], p[1])

count_parent = 0
for i in unionFind.parents:
    if i < 0:
        count_parent += 1
if count_parent == 1 and result_flag and (N == 1 or set(counter) == set([1, 2])):
    print("Yes")
else:
    print("No")



def resolve():
    import sys

    input = sys.stdin.readline
    t = int(input())
    for _ in range(t):
        k = int(input())
        if k == 1:
            print(1)
            continue

        m = 9 * k if k % 2 else 9 * k // 2
        try:
            ans = bsgs(10, pow(10, -1, m), m)
            print(ans + 2 if ans >= 0 else -1)
        except:
            print(-1)


def bsgs(a, b, m, is_prime=False):
    # a^x = b (mod m) たる最小のx
    def inv(a, m):
        x, y = 1, 0
        while m != 0:
            x, y = y, x - (a // m) * y
            a, m = m, a % m
        return x

    if m == 1:
        return 0
    if a == 0:
        if b <= 1:
            return b ^ 1
        return -1

    # gcd(a,m) == 1 にする
    import math

    c = 0
    while True:
        if m == 1:
            return c
        g = math.gcd(a, m)
        if g == 1:
            break
        if b % g:
            return -1
        b //= g
        m //= g
        if is_prime:
            b *= pow(a // g, m - 2, m)
        else:
            b *= inv(a // g, m)
        b %= m
        c += 1

    # baby step
    r = int(m**0.5) + 1
    baby = {}
    x = a
    for i in range(r):
        baby[x] = i
        if x == b:
            return i + c
        x *= a
        x %= m
    x *= inv(a, m)
    x %= m
    # giant step x:a^r
    if is_prime:
        inv_ar = pow(x, m - 2, m)
    else:
        inv_ar = inv(x, m)
    for j in range(1, r + 1):
        b *= inv_ar
        b %= m
        if b in baby:
            return j * r + baby[b] + c

    return -1


if __name__ == "__main__":
    resolve()



N = int(input())
mod = 998244353

dp = [[0] * 11 for _ in range(N)]

for i in range(1, 10):
    dp[0][i] = 1

for i in range(N - 1):
    for j in range(1, 10):
        dp[i + 1][j] = (dp[i][j - 1] + dp[i][j] + dp[i][j + 1]) % mod

for d in dp:
    print(d)
print(sum(dp[-1]) % mod)



n = int(input())
q = list(map(int, input().split()))
a = list(map(int, input().split()))
b = list(map(int, input().split()))
ans = 0
inf = float("inf")
for x in range(max(q) + 1):
    y = inf
    for i in range(n):
        if q[i] < x * a[i]:
            y = -inf
            break
        elif b[i] > 0:
            y = min((q[i] - x * a[i]) // b[i], x)
    ans = max(ans, x + y)
print(ans)



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 10\n1 3\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '3\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 1\n2 3\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '0\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='4 12\n3 3 3 3\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '3\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='7 251\n202 20 5 1 4 2 100\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '48\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='20 100\n36 49 73 38 30 85 27 45 65 71 52 86 52 48 60 40 98 37 38 5\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '60\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



N = int(input())
l = list(map(int, input().split()))
lis = []
d = []
b = 0
for j in range(int(N / 7)):
    for k in l[7 * b : 7 * (b + 1)]:
        lis.append(k)
    d.append(sum(lis))
    lis.clear()
    b += 1
print(*d)



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.minimumDeletions([2, 10, 7, 5, 4, 1, 8, 6])
    assert result == 5


def test_case_1():
    sol = Solution()
    result = sol.minimumDeletions([0, -4, 19, 1, 8, -2, -3, 5])
    assert result == 3


def test_case_2():
    sol = Solution()
    result = sol.minimumDeletions([101])
    assert result == 1



from collections import deque
from collections import defaultdict
import sys

sys.setrecursionlimit(1000000)
s = input()
t = []
for i in s:
    t.append(i)

k = 0
for i in range(len(t)):
    if t[i] == "(":
        k += 1
    elif t[i] == ")":
        k -= 1
    else:
        if k % 2 == 1:
            if ord(t[i]) - ord("A") < 26:
                t[i] = chr(ord(t[i]) - ord("A") + ord("a"))
            else:
                t[i] = chr(ord(t[i]) + ord("A") - ord("a"))
# print(t)
pi = defaultdict(int)
ppi = defaultdict(int)
kakko = [0 for i in range(len(t))]
# kk=0
qu = []
for i in range(len(t)):
    if t[i] == "(":
        # kk+=1
        qu.append(i)
        # pi[kk]=i
        # kakko[i]=kk
    elif t[i] == ")":
        r = qu.pop(-1)
        ppi[i] = r
        ppi[r] = i
print(ppi)


# kakko[i]=-qu.pop(-1)
# print(kakko)
def kai(s, f, u):
    # print("p",s,f,u,"p")
    # if s==f:
    # return
    if u == 0:
        i = s
        while s <= i < f:
            # for i in range(s,f):
            if t[i] == "(":
                p = ppi[i]
                # p=kakko.index(-kakko[i])
                kai(i, p, 1)
                i = p + 1
            elif t[i] == ")":
                break
            else:
                print(t[i], end="")
                i += 1
    else:
        i = f - 1
        while s <= i < f:
            # for i in reversed(range(s,f)):
            if t[i] == ")":
                p = ppi[i]
                # p=kakko.index(-kakko[i])
                kai(p + 1, i, 0)
                i = p - 1
            elif t[i] == "(":
                break
            else:
                print(t[i], end="")
                i -= 1


kai(0, len(t), 0)
print()



from collections import *
import heapq
import bisect

INF = float("inf")
MOD = 998244353
mod = 998244353


X = list(input())
num = [0]
for x in X:
    num.append(num[-1] + int(x))
num.reverse()
L = len(num)
ans = []
for i in range(L - 1):
    k = num[i]
    p, r = divmod(k, 10)
    ans.append(str(r))
    num[i + 1] += p
ans.reverse()
print("".join(ans))



N, M = map(int, input().split())
L = list(map(int, input().split()))


def isok(n):
    dist = -1
    count = 0
    for i in range(N):
        if L[i] > n:
            return False
        if dist + 1 + L[i] > n:
            dist = -1
            count += 1
        dist += 1 + L[i]
    if count + 1 <= M:
        return True
    return False


left, right = 0, 10**10
while right - left > 1:
    mid = (right + left) // 2
    if isok(mid):
        right = mid
    else:
        left = mid
print(right)



import json
from pathlib import Path


def load_threshold() -> int:
    base = Path(__file__).resolve().parent
    text = (base / "config" / "settings").read_text(encoding="utf-8")
    return int(json.loads(text)["threshold"])



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3\n3 2 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='4\n3 3 3 3\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10\n73 8 55 26 97 48 37 47 35 55\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='100\n5 17 62 2 60 23 99 73 34 75 7 46 82 84 29 41 32 31 52 32 60 51 95 37 1 68 48 35 18 1 68 26 27 11 47 78 73 54 27 91 48 2 63 60 77 75 80 41 79 60 2 81 51 59 33 96 92 67 76 89 5 84 49 76 68 80 63 33 96 22 72 19 56 51 89 29 25 61 9 19 73 92 83 27 55 81 15 67 2 95 95 6 55 54 98 95 59 54 70 51\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='100\n69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69 69\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



N, M = map(int, input().split())
G = [[] for _ in range(N)]
for _ in range(M):
    u, v = map(int, input().split())
    G[u - 1].append(v - 1)
    G[v - 1].append(u - 1)
seen = set()
cnt = 0
for i in range(N):
    if i not in seen:
        stack = [i]
        cnt += 1
        while stack:
            x = stack.pop()
            if x in seen:
                continue
            seen.add(x)
            for j in G[i]:
                if j not in seen:
                    stack.append(j)
print(cnt)



def job():
    n, a, b = map(int, input().split())
    s = input()
    a_sum = 0
    a_min = 0
    a = min(a, 2 * b)
    left = s.count(")")
    right = s.count("(")
    s = list(s)
    ans = 0
    diff = abs(right - left)
    cnt = diff // 2
    ans += b * cnt
    tot = 0
    if left > right:
        for i in range(2 * n):
            if tot == cnt:
                break
            c = s[i]
            if c == ")":
                s[i] = "("
                tot += 1
    else:
        for i in reversed(range(2 * n)):
            if tot == cnt:
                break
            c = s[i]
            if c == "(":
                s[i] = ")"
                tot += 1
    for c in s:
        if c == "(":
            a_sum += 1
        else:
            a_sum -= 1
        a_min = min(a_sum, a_min)
    swap_count = abs(a_min // 2)
    if abs(a_min) % 2 == 1:
        swap_count += 1

    ans += a * swap_count
    print(ans)


job()
